/* THIS SAMPLE CODE IS PROVIDED AS IS AND IS SUBJECT TO ALTERATIONS. FUJITSU */
/* MICROELECTRONICS ACCEPTS NO RESPONSIBILITY OR LIABILITY FOR ANY ERRORS OR */
/* ELIGIBILITY FOR ANY PURPOSES.                                             */
/*                 (C) Fujitsu Microelectronics Europe GmbH                  */
/*---------------------------------------------------------------------------*/

#include <project.h>
#include "speech.h"
#include "FatFs\diskio.h"
#include "FatFs\ff.h"

#define DB

#ifdef DB
    #include <stdio.h>
    char szPrintf[32];
#endif
    
FATFS fatFs;

// --------------------------------
// --- SPEECH (Low-Level: hardware)
// --------------------------------



// --------------------------------
// --- SPEECH (Low-Level: software)
// --------------------------------


//
// SPEECH OUT (Play)
//

FIL speech_play_file;
unsigned char speech_out_status;           // status of speech_out 
volatile unsigned long speech_out_cnt;     // number of bytes processed
volatile unsigned char speech_out_value;   // audio value to be output
unsigned long speech_out_memory_cnt;       // number of bytes available on USB memory

// Speech Out Buffer: Temporary buffer for aynchronous handling between USB transfer and outgoing audio data

unsigned char speech_out_buffer[SPEECH_OUT_BUFFER_MAX];
unsigned int  speech_out_buffer_write_adr; // points to the next buffer position to be written
unsigned int  speech_out_buffer_read_adr;  // points to the next buffer position to be read
unsigned int  speech_out_buffer_cnt;       // number of bytes in the buffer
unsigned int  speech_out_buffer_USB_adr;   // points to the next buffer position to be read next block

void speech_out_buffer_clear()
{
  speech_out_buffer_write_adr  = 0;
  speech_out_buffer_read_adr   = 0;
  speech_out_buffer_cnt        = 0;
  speech_out_buffer_USB_adr    = 0;
}


unsigned char speech_out_buffer_read(void)
// readout one byte from speech-out buffer
{
  unsigned char temp;
  CyGlobalIntDisable;
  if (speech_out_buffer_cnt > 0)
  {
    speech_out_buffer_cnt = speech_out_buffer_cnt - 1;  
    temp = speech_out_buffer[speech_out_buffer_read_adr];     
    speech_out_buffer_read_adr = speech_out_buffer_read_adr + 1;
    if (speech_out_buffer_read_adr >= SPEECH_OUT_BUFFER_MAX)
      speech_out_buffer_read_adr = 0;
  }
  else
  {
    temp = 0;
    speech_out_status = SPEECH_OUT_STATUS_PLAY_ERRREAD; // please no read access if buffer is empty
  }
  CyGlobalIntEnable;
  return(temp);
}

void Speech_Out_USB_to_Buffer(void)
// transfers blocks from USB to the speech-out buffer 
{
  unsigned int blocksize_request, blocksize_read;
  	
  if (speech_out_memory_cnt > 0) // if still data to be read ...
  {
  
    if ((SPEECH_OUT_BUFFER_MAX - speech_out_buffer_cnt) >= SPEECH_OUT_USB_BLOCK)
    {
      if (speech_out_memory_cnt > SPEECH_OUT_USB_BLOCK)
      {
        blocksize_request = SPEECH_OUT_USB_BLOCK;
      }
      else
      {
        blocksize_request = speech_out_memory_cnt; // read last bytes
      }
      f_read(&speech_play_file, &speech_out_buffer[speech_out_buffer_USB_adr], blocksize_request, &blocksize_read);
      
      CyGlobalIntDisable;
      speech_out_memory_cnt = speech_out_memory_cnt - blocksize_read;
      speech_out_buffer_cnt = speech_out_buffer_cnt + blocksize_read;  
      
      if (blocksize_request != blocksize_read)
      {
        speech_out_status = SPEECH_OUT_STATUS_PLAY_ERRBUF;
        #ifdef DB
          UART_PutString("\r*** Unexpected number of data read from buffer ***");
        #endif
      }
      else
      {
        speech_out_buffer_USB_adr = speech_out_buffer_USB_adr + SPEECH_OUT_USB_BLOCK;
        if (speech_out_buffer_USB_adr >= SPEECH_OUT_BUFFER_MAX)
          speech_out_buffer_USB_adr = 0;
      }
      CyGlobalIntEnable;
    }
  } // if (speech_out_memory_cnt > 0)
}

// --------------------------------------
// --- SPEECH (High-Level: software / API
// --------------------------------------

void Speech_Init(void)
// Initializes the Speech interface
{
    IDAC_Start();
    Opamp_Start();
    
    speech_out_status = SPEECH_OUT_STATUS_IDLE;
}

//
// SPEECH API (Play)
//

unsigned char Speech_Out_Status()
// returns the status of Speech-Out operation
{
  return (speech_out_status);
}

void Speech_Out_Start( char* filename)
{
  FILINFO finfo;

  f_mount(&fatFs, "", 1u);
  f_open(&speech_play_file, filename, FA_READ);
  f_stat(filename, &finfo);
  speech_out_buffer_clear();
  speech_out_memory_cnt = finfo.fsize;  // number of bytes to be transferred to internal buffer
  speech_out_cnt = finfo.fsize;         // number of bytes to be output
  //speech_out_cnt = ((finfo.fsize & 0xff) << 24) + ((finfo.fsize & 0xff00) << 8) + ((finfo.fsize & 0xff0000) >> 8) + ((finfo.fsize & 0xff000000) >> 24);
  #ifdef DB
    UART_PutString("\r\rPLAY");
    UART_PutString("\rFilename: ");
    UART_PutString(filename);
    sprintf(szPrintf, "\rFileSize: %lu Bytes\r", speech_out_cnt);
    UART_PutString(szPrintf);
  #endif
  
  while ( (speech_out_memory_cnt) && (speech_out_buffer_cnt < SPEECH_OUT_BUFFER_MAX) )
  {
    Speech_Out_USB_to_Buffer(); // Fillup the internal buffer
  }
  
  speech_out_value = speech_out_buffer_read(); // prepare first data output
  speech_out_status = SPEECH_OUT_STATUS_PLAY;
}

void Speech_Out_Stop(void)
{
  #ifdef DB
    UART_PutString("\rPLAY Stop");
  #endif

  speech_out_status = SPEECH_OUT_STATUS_PLAY_FINISH;
  f_close(&speech_play_file);
}


// 
// --- Interrupts
// 

void Speech_ISR(void)
{
//
// SPEECH-OUT (Play)
//  
  if (speech_out_status == SPEECH_OUT_STATUS_PLAY)
  {
    #if (SPEECH_DAC_WIDTH == 7)
        IDAC_SetValue(speech_out_value>>1);
    #elif (SPEECH_DAC_WIDTH == 8)
        IDAC_SetValue(speech_out_value);
    #else 
        #error Define SPEECH_DAC_WIDTH (7 or 8) in speech.h
    #endif
     
    //UART_PutChar('.');
    
    speech_out_cnt = speech_out_cnt - 1;                    // decrease number of bytes to be sent
    if (speech_out_cnt > 0)                                 // Still data?
    {
      speech_out_value = speech_out_buffer_read();          // prepare next data output
    }
    else
    {
      speech_out_status = SPEECH_OUT_STATUS_PLAY_STOP;      // Stop playing
    }
  }
}

unsigned char Speech_File_Check( char* filename)
{
  FILINFO test_file_info;
  unsigned char result;
  
//  result = f_open(&test_file, filename, FA_READ);
//  f_close(&test_file);

  result = f_stat(filename, &test_file_info);
  return(result);
}

//============================================================================
// ----------------------- End of File ---------------------------------------
//============================================================================


