/*******************************************************************************
* File Name: TimerSpeech.c
* Version 2.10
*
* Description:
*  This file provides the source code to the API for the TimerSpeech
*  component
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerSpeech.h"

uint8 TimerSpeech_initVar = 0u;


/*******************************************************************************
* Function Name: TimerSpeech_Init
********************************************************************************
*
* Summary:
*  Initialize/Restore default TimerSpeech configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_Init(void)
{

    /* Set values from customizer to CTRL */
    #if (TimerSpeech__QUAD == TimerSpeech_CONFIG)
        TimerSpeech_CONTROL_REG = TimerSpeech_CTRL_QUAD_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        TimerSpeech_TRIG_CONTROL1_REG  = TimerSpeech_QUAD_SIGNALS_MODES;

        /* Set values from customizer to INTR */
        TimerSpeech_SetInterruptMode(TimerSpeech_QUAD_INTERRUPT_MASK);
        
         /* Set other values */
        TimerSpeech_SetCounterMode(TimerSpeech_COUNT_DOWN);
        TimerSpeech_WritePeriod(TimerSpeech_QUAD_PERIOD_INIT_VALUE);
        TimerSpeech_WriteCounter(TimerSpeech_QUAD_PERIOD_INIT_VALUE);
    #endif  /* (TimerSpeech__QUAD == TimerSpeech_CONFIG) */

    #if (TimerSpeech__TIMER == TimerSpeech_CONFIG)
        TimerSpeech_CONTROL_REG = TimerSpeech_CTRL_TIMER_BASE_CONFIG;
        
        /* Set values from customizer to CTRL1 */
        TimerSpeech_TRIG_CONTROL1_REG  = TimerSpeech_TIMER_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        TimerSpeech_SetInterruptMode(TimerSpeech_TC_INTERRUPT_MASK);
        
        /* Set other values from customizer */
        TimerSpeech_WritePeriod(TimerSpeech_TC_PERIOD_VALUE );

        #if (TimerSpeech__COMPARE == TimerSpeech_TC_COMP_CAP_MODE)
            TimerSpeech_WriteCompare(TimerSpeech_TC_COMPARE_VALUE);

            #if (1u == TimerSpeech_TC_COMPARE_SWAP)
                TimerSpeech_SetCompareSwap(1u);
                TimerSpeech_WriteCompareBuf(TimerSpeech_TC_COMPARE_BUF_VALUE);
            #endif  /* (1u == TimerSpeech_TC_COMPARE_SWAP) */
        #endif  /* (TimerSpeech__COMPARE == TimerSpeech_TC_COMP_CAP_MODE) */

        /* Initialize counter value */
        #if (TimerSpeech_CY_TCPWM_V2 && TimerSpeech_TIMER_UPDOWN_CNT_USED && !TimerSpeech_CY_TCPWM_4000)
            TimerSpeech_WriteCounter(1u);
        #elif(TimerSpeech__COUNT_DOWN == TimerSpeech_TC_COUNTER_MODE)
            TimerSpeech_WriteCounter(TimerSpeech_TC_PERIOD_VALUE);
        #else
            TimerSpeech_WriteCounter(0u);
        #endif /* (TimerSpeech_CY_TCPWM_V2 && TimerSpeech_TIMER_UPDOWN_CNT_USED && !TimerSpeech_CY_TCPWM_4000) */
    #endif  /* (TimerSpeech__TIMER == TimerSpeech_CONFIG) */

    #if (TimerSpeech__PWM_SEL == TimerSpeech_CONFIG)
        TimerSpeech_CONTROL_REG = TimerSpeech_CTRL_PWM_BASE_CONFIG;

        #if (TimerSpeech__PWM_PR == TimerSpeech_PWM_MODE)
            TimerSpeech_CONTROL_REG |= TimerSpeech_CTRL_PWM_RUN_MODE;
            TimerSpeech_WriteCounter(TimerSpeech_PWM_PR_INIT_VALUE);
        #else
            TimerSpeech_CONTROL_REG |= TimerSpeech_CTRL_PWM_ALIGN | TimerSpeech_CTRL_PWM_KILL_EVENT;
            
            /* Initialize counter value */
            #if (TimerSpeech_CY_TCPWM_V2 && TimerSpeech_PWM_UPDOWN_CNT_USED && !TimerSpeech_CY_TCPWM_4000)
                TimerSpeech_WriteCounter(1u);
            #elif (TimerSpeech__RIGHT == TimerSpeech_PWM_ALIGN)
                TimerSpeech_WriteCounter(TimerSpeech_PWM_PERIOD_VALUE);
            #else 
                TimerSpeech_WriteCounter(0u);
            #endif  /* (TimerSpeech_CY_TCPWM_V2 && TimerSpeech_PWM_UPDOWN_CNT_USED && !TimerSpeech_CY_TCPWM_4000) */
        #endif  /* (TimerSpeech__PWM_PR == TimerSpeech_PWM_MODE) */

        #if (TimerSpeech__PWM_DT == TimerSpeech_PWM_MODE)
            TimerSpeech_CONTROL_REG |= TimerSpeech_CTRL_PWM_DEAD_TIME_CYCLE;
        #endif  /* (TimerSpeech__PWM_DT == TimerSpeech_PWM_MODE) */

        #if (TimerSpeech__PWM == TimerSpeech_PWM_MODE)
            TimerSpeech_CONTROL_REG |= TimerSpeech_CTRL_PWM_PRESCALER;
        #endif  /* (TimerSpeech__PWM == TimerSpeech_PWM_MODE) */

        /* Set values from customizer to CTRL1 */
        TimerSpeech_TRIG_CONTROL1_REG  = TimerSpeech_PWM_SIGNALS_MODES;
    
        /* Set values from customizer to INTR */
        TimerSpeech_SetInterruptMode(TimerSpeech_PWM_INTERRUPT_MASK);

        /* Set values from customizer to CTRL2 */
        #if (TimerSpeech__PWM_PR == TimerSpeech_PWM_MODE)
            TimerSpeech_TRIG_CONTROL2_REG =
                    (TimerSpeech_CC_MATCH_NO_CHANGE    |
                    TimerSpeech_OVERLOW_NO_CHANGE      |
                    TimerSpeech_UNDERFLOW_NO_CHANGE);
        #else
            #if (TimerSpeech__LEFT == TimerSpeech_PWM_ALIGN)
                TimerSpeech_TRIG_CONTROL2_REG = TimerSpeech_PWM_MODE_LEFT;
            #endif  /* ( TimerSpeech_PWM_LEFT == TimerSpeech_PWM_ALIGN) */

            #if (TimerSpeech__RIGHT == TimerSpeech_PWM_ALIGN)
                TimerSpeech_TRIG_CONTROL2_REG = TimerSpeech_PWM_MODE_RIGHT;
            #endif  /* ( TimerSpeech_PWM_RIGHT == TimerSpeech_PWM_ALIGN) */

            #if (TimerSpeech__CENTER == TimerSpeech_PWM_ALIGN)
                TimerSpeech_TRIG_CONTROL2_REG = TimerSpeech_PWM_MODE_CENTER;
            #endif  /* ( TimerSpeech_PWM_CENTER == TimerSpeech_PWM_ALIGN) */

            #if (TimerSpeech__ASYMMETRIC == TimerSpeech_PWM_ALIGN)
                TimerSpeech_TRIG_CONTROL2_REG = TimerSpeech_PWM_MODE_ASYM;
            #endif  /* (TimerSpeech__ASYMMETRIC == TimerSpeech_PWM_ALIGN) */
        #endif  /* (TimerSpeech__PWM_PR == TimerSpeech_PWM_MODE) */

        /* Set other values from customizer */
        TimerSpeech_WritePeriod(TimerSpeech_PWM_PERIOD_VALUE );
        TimerSpeech_WriteCompare(TimerSpeech_PWM_COMPARE_VALUE);

        #if (1u == TimerSpeech_PWM_COMPARE_SWAP)
            TimerSpeech_SetCompareSwap(1u);
            TimerSpeech_WriteCompareBuf(TimerSpeech_PWM_COMPARE_BUF_VALUE);
        #endif  /* (1u == TimerSpeech_PWM_COMPARE_SWAP) */

        #if (1u == TimerSpeech_PWM_PERIOD_SWAP)
            TimerSpeech_SetPeriodSwap(1u);
            TimerSpeech_WritePeriodBuf(TimerSpeech_PWM_PERIOD_BUF_VALUE);
        #endif  /* (1u == TimerSpeech_PWM_PERIOD_SWAP) */
    #endif  /* (TimerSpeech__PWM_SEL == TimerSpeech_CONFIG) */
    
}


/*******************************************************************************
* Function Name: TimerSpeech_Enable
********************************************************************************
*
* Summary:
*  Enables the TimerSpeech.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_Enable(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();
    TimerSpeech_BLOCK_CONTROL_REG |= TimerSpeech_MASK;
    CyExitCriticalSection(enableInterrupts);

    /* Start Timer or PWM if start input is absent */
    #if (TimerSpeech__PWM_SEL == TimerSpeech_CONFIG)
        #if (0u == TimerSpeech_PWM_START_SIGNAL_PRESENT)
            TimerSpeech_TriggerCommand(TimerSpeech_MASK, TimerSpeech_CMD_START);
        #endif /* (0u == TimerSpeech_PWM_START_SIGNAL_PRESENT) */
    #endif /* (TimerSpeech__PWM_SEL == TimerSpeech_CONFIG) */

    #if (TimerSpeech__TIMER == TimerSpeech_CONFIG)
        #if (0u == TimerSpeech_TC_START_SIGNAL_PRESENT)
            TimerSpeech_TriggerCommand(TimerSpeech_MASK, TimerSpeech_CMD_START);
        #endif /* (0u == TimerSpeech_TC_START_SIGNAL_PRESENT) */
    #endif /* (TimerSpeech__TIMER == TimerSpeech_CONFIG) */
    
    #if (TimerSpeech__QUAD == TimerSpeech_CONFIG)
        #if (0u != TimerSpeech_QUAD_AUTO_START)
            TimerSpeech_TriggerCommand(TimerSpeech_MASK, TimerSpeech_CMD_RELOAD);
        #endif /* (0u != TimerSpeech_QUAD_AUTO_START) */
    #endif  /* (TimerSpeech__QUAD == TimerSpeech_CONFIG) */
}


/*******************************************************************************
* Function Name: TimerSpeech_Start
********************************************************************************
*
* Summary:
*  Initializes the TimerSpeech with default customizer
*  values when called the first time and enables the TimerSpeech.
*  For subsequent calls the configuration is left unchanged and the component is
*  just enabled.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  TimerSpeech_initVar: global variable is used to indicate initial
*  configuration of this component.  The variable is initialized to zero and set
*  to 1 the first time TimerSpeech_Start() is called. This allows
*  enabling/disabling a component without re-initialization in all subsequent
*  calls to the TimerSpeech_Start() routine.
*
*******************************************************************************/
void TimerSpeech_Start(void)
{
    if (0u == TimerSpeech_initVar)
    {
        TimerSpeech_Init();
        TimerSpeech_initVar = 1u;
    }

    TimerSpeech_Enable();
}


/*******************************************************************************
* Function Name: TimerSpeech_Stop
********************************************************************************
*
* Summary:
*  Disables the TimerSpeech.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_Stop(void)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_BLOCK_CONTROL_REG &= (uint32)~TimerSpeech_MASK;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetMode
********************************************************************************
*
* Summary:
*  Sets the operation mode of the TimerSpeech. This function is used when
*  configured as a generic TimerSpeech and the actual mode of operation is
*  set at runtime. The mode must be set while the component is disabled.
*
* Parameters:
*  mode: Mode for the TimerSpeech to operate in
*   Values:
*   - TimerSpeech_MODE_TIMER_COMPARE - Timer / Counter with
*                                                 compare capability
*         - TimerSpeech_MODE_TIMER_CAPTURE - Timer / Counter with
*                                                 capture capability
*         - TimerSpeech_MODE_QUAD - Quadrature decoder
*         - TimerSpeech_MODE_PWM - PWM
*         - TimerSpeech_MODE_PWM_DT - PWM with dead time
*         - TimerSpeech_MODE_PWM_PR - PWM with pseudo random capability
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetMode(uint32 mode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_MODE_MASK;
    TimerSpeech_CONTROL_REG |= mode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetQDMode
********************************************************************************
*
* Summary:
*  Sets the the Quadrature Decoder to one of the 3 supported modes.
*  Its functionality is only applicable to Quadrature Decoder operation.
*
* Parameters:
*  qdMode: Quadrature Decoder mode
*   Values:
*         - TimerSpeech_MODE_X1 - Counts on phi 1 rising
*         - TimerSpeech_MODE_X2 - Counts on both edges of phi1 (2x faster)
*         - TimerSpeech_MODE_X4 - Counts on both edges of phi1 and phi2
*                                        (4x faster)
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetQDMode(uint32 qdMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_QUAD_MODE_MASK;
    TimerSpeech_CONTROL_REG |= qdMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPrescaler
********************************************************************************
*
* Summary:
*  Sets the prescaler value that is applied to the clock input.  Not applicable
*  to a PWM with the dead time mode or Quadrature Decoder mode.
*
* Parameters:
*  prescaler: Prescaler divider value
*   Values:
*         - TimerSpeech_PRESCALE_DIVBY1    - Divide by 1 (no prescaling)
*         - TimerSpeech_PRESCALE_DIVBY2    - Divide by 2
*         - TimerSpeech_PRESCALE_DIVBY4    - Divide by 4
*         - TimerSpeech_PRESCALE_DIVBY8    - Divide by 8
*         - TimerSpeech_PRESCALE_DIVBY16   - Divide by 16
*         - TimerSpeech_PRESCALE_DIVBY32   - Divide by 32
*         - TimerSpeech_PRESCALE_DIVBY64   - Divide by 64
*         - TimerSpeech_PRESCALE_DIVBY128  - Divide by 128
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPrescaler(uint32 prescaler)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_PRESCALER_MASK;
    TimerSpeech_CONTROL_REG |= prescaler;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetOneShot
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the TimerSpeech runs
*  continuously or stops when terminal count is reached.  By default the
*  TimerSpeech operates in the continuous mode.
*
* Parameters:
*  oneShotEnable
*   Values:
*     - 0 - Continuous
*     - 1 - Enable One Shot
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetOneShot(uint32 oneShotEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_ONESHOT_MASK;
    TimerSpeech_CONTROL_REG |= ((uint32)((oneShotEnable & TimerSpeech_1BIT_MASK) <<
                                                               TimerSpeech_ONESHOT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPWMMode
********************************************************************************
*
* Summary:
*  Writes the control register that determines what mode of operation the PWM
*  output lines are driven in.  There is a setting for what to do on a
*  comparison match (CC_MATCH), on an overflow (OVERFLOW) and on an underflow
*  (UNDERFLOW).  The value for each of the three must be ORed together to form
*  the mode.
*
* Parameters:
*  modeMask: A combination of three mode settings.  Mask must include a value
*  for each of the three or use one of the preconfigured PWM settings.
*   Values:
*     - CC_MATCH_SET        - Set on comparison match
*     - CC_MATCH_CLEAR      - Clear on comparison match
*     - CC_MATCH_INVERT     - Invert on comparison match
*     - CC_MATCH_NO_CHANGE  - No change on comparison match
*     - OVERLOW_SET         - Set on overflow
*     - OVERLOW_CLEAR       - Clear on  overflow
*     - OVERLOW_INVERT      - Invert on overflow
*     - OVERLOW_NO_CHANGE   - No change on overflow
*     - UNDERFLOW_SET       - Set on underflow
*     - UNDERFLOW_CLEAR     - Clear on underflow
*     - UNDERFLOW_INVERT    - Invert on underflow
*     - UNDERFLOW_NO_CHANGE - No change on underflow
*     - PWM_MODE_LEFT       - Setting for left aligned PWM.  Should be combined
*                             with up counting mode
*     - PWM_MODE_RIGHT      - Setting for right aligned PWM.  Should be combined
*                             with down counting mode
*     - PWM_MODE_CENTER     - Setting for center aligned PWM.  Should be
*                             combined with up/down 0 mode
*     - PWM_MODE_ASYM       - Setting for asymmetric PWM.  Should be combined
*                             with up/down 1 mode
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPWMMode(uint32 modeMask)
{
    TimerSpeech_TRIG_CONTROL2_REG = (modeMask & TimerSpeech_6BIT_MASK);
}



/*******************************************************************************
* Function Name: TimerSpeech_SetPWMSyncKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes asynchronous or synchronous kill operation.  By default the kill
*  operation is asynchronous.  This functionality is only applicable to the PWM
*  and PWM with dead time modes.
*
*  For Synchronous mode the kill signal disables both the line and line_n
*  signals until the next terminal count.
*
*  For Asynchronous mode the kill signal disables both the line and line_n
*  signals when the kill signal is present.  This mode should only be used
*  when the kill signal (stop input) is configured in the pass through mode
*  (Level sensitive signal).

*
* Parameters:
*  syncKillEnable
*   Values:
*     - 0 - Asynchronous
*     - 1 - Synchronous
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPWMSyncKill(uint32 syncKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_PWM_SYNC_KILL_MASK;
    TimerSpeech_CONTROL_REG |= ((uint32)((syncKillEnable & TimerSpeech_1BIT_MASK)  <<
                                               TimerSpeech_PWM_SYNC_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPWMStopOnKill
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the PWM kill signal (stop input)
*  causes the PWM counter to stop.  By default the kill operation does not stop
*  the counter.  This functionality is only applicable to the three PWM modes.
*
*
* Parameters:
*  stopOnKillEnable
*   Values:
*     - 0 - Don't stop
*     - 1 - Stop
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPWMStopOnKill(uint32 stopOnKillEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_PWM_STOP_KILL_MASK;
    TimerSpeech_CONTROL_REG |= ((uint32)((stopOnKillEnable & TimerSpeech_1BIT_MASK)  <<
                                                         TimerSpeech_PWM_STOP_KILL_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPWMDeadTime
********************************************************************************
*
* Summary:
*  Writes the dead time control value.  This value delays the rising edge of
*  both the line and line_n signals the designated number of cycles resulting
*  in both signals being inactive for that many cycles.  This functionality is
*  only applicable to the PWM in the dead time mode.

*
* Parameters:
*  Dead time to insert
*   Values: 0 to 255
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPWMDeadTime(uint32 deadTime)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_PRESCALER_MASK;
    TimerSpeech_CONTROL_REG |= ((uint32)((deadTime & TimerSpeech_8BIT_MASK) <<
                                                          TimerSpeech_PRESCALER_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPWMInvert
********************************************************************************
*
* Summary:
*  Writes the bits that control whether the line and line_n outputs are
*  inverted from their normal output values.  This functionality is only
*  applicable to the three PWM modes.
*
* Parameters:
*  mask: Mask of outputs to invert.
*   Values:
*         - TimerSpeech_INVERT_LINE   - Inverts the line output
*         - TimerSpeech_INVERT_LINE_N - Inverts the line_n output
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPWMInvert(uint32 mask)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_INV_OUT_MASK;
    TimerSpeech_CONTROL_REG |= mask;

    CyExitCriticalSection(enableInterrupts);
}



/*******************************************************************************
* Function Name: TimerSpeech_WriteCounter
********************************************************************************
*
* Summary:
*  Writes a new 16bit counter value directly into the counter register, thus
*  setting the counter (not the period) to the value written. It is not
*  advised to write to this field when the counter is running.
*
* Parameters:
*  count: value to write
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_WriteCounter(uint32 count)
{
    TimerSpeech_COUNTER_REG = (count & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadCounter
********************************************************************************
*
* Summary:
*  Reads the current counter value.
*
* Parameters:
*  None
*
* Return:
*  Current counter value
*
*******************************************************************************/
uint32 TimerSpeech_ReadCounter(void)
{
    return (TimerSpeech_COUNTER_REG & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetCounterMode
********************************************************************************
*
* Summary:
*  Sets the counter mode.  Applicable to all modes except Quadrature Decoder
*  and the PWM with a pseudo random output.
*
* Parameters:
*  counterMode: Enumerated counter type values
*   Values:
*     - TimerSpeech_COUNT_UP       - Counts up
*     - TimerSpeech_COUNT_DOWN     - Counts down
*     - TimerSpeech_COUNT_UPDOWN0  - Counts up and down. Terminal count
*                                         generated when counter reaches 0
*     - TimerSpeech_COUNT_UPDOWN1  - Counts up and down. Terminal count
*                                         generated both when counter reaches 0
*                                         and period
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetCounterMode(uint32 counterMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_UPDOWN_MASK;
    TimerSpeech_CONTROL_REG |= counterMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_WritePeriod
********************************************************************************
*
* Summary:
*  Writes the 16 bit period register with the new period value.
*  To cause the counter to count for N cycles this register should be written
*  with N-1 (counts from 0 to period inclusive).
*
* Parameters:
*  period: Period value
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_WritePeriod(uint32 period)
{
    TimerSpeech_PERIOD_REG = (period & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the 16 bit period register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 TimerSpeech_ReadPeriod(void)
{
    return (TimerSpeech_PERIOD_REG & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetCompareSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the compare registers are
*  swapped. When enabled in the Timer/Counter mode(without capture) the swap
*  occurs at a TC event. In the PWM mode the swap occurs at the next TC event
*  following a hardware switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetCompareSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_RELOAD_CC_MASK;
    TimerSpeech_CONTROL_REG |= (swapEnable & TimerSpeech_1BIT_MASK);

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_WritePeriodBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit period buf register with the new period value.
*
* Parameters:
*  periodBuf: Period value
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_WritePeriodBuf(uint32 periodBuf)
{
    TimerSpeech_PERIOD_BUF_REG = (periodBuf & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadPeriodBuf
********************************************************************************
*
* Summary:
*  Reads the 16 bit period buf register.
*
* Parameters:
*  None
*
* Return:
*  Period value
*
*******************************************************************************/
uint32 TimerSpeech_ReadPeriodBuf(void)
{
    return (TimerSpeech_PERIOD_BUF_REG & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetPeriodSwap
********************************************************************************
*
* Summary:
*  Writes the register that controls whether the period registers are
*  swapped. When enabled in Timer/Counter mode the swap occurs at a TC event.
*  In the PWM mode the swap occurs at the next TC event following a hardware
*  switch event.
*
* Parameters:
*  swapEnable
*   Values:
*     - 0 - Disable swap
*     - 1 - Enable swap
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetPeriodSwap(uint32 swapEnable)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_CONTROL_REG &= (uint32)~TimerSpeech_RELOAD_PERIOD_MASK;
    TimerSpeech_CONTROL_REG |= ((uint32)((swapEnable & TimerSpeech_1BIT_MASK) <<
                                                            TimerSpeech_RELOAD_PERIOD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_WriteCompare
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compare: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void TimerSpeech_WriteCompare(uint32 compare)
{
    #if (TimerSpeech_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (TimerSpeech_CY_TCPWM_4000) */

    #if (TimerSpeech_CY_TCPWM_4000)
        currentMode = ((TimerSpeech_CONTROL_REG & TimerSpeech_UPDOWN_MASK) >> TimerSpeech_UPDOWN_SHIFT);

        if (((uint32)TimerSpeech__COUNT_DOWN == currentMode) && (0xFFFFu != compare))
        {
            compare++;
        }
        else if (((uint32)TimerSpeech__COUNT_UP == currentMode) && (0u != compare))
        {
            compare--;
        }
        else
        {
        }
        
    
    #endif /* (TimerSpeech_CY_TCPWM_4000) */
    
    TimerSpeech_COMP_CAP_REG = (compare & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadCompare
********************************************************************************
*
* Summary:
*  Reads the compare register. Not applicable for Timer/Counter with Capture
*  or in Quadrature Decoder modes.
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
* Parameters:
*  None
*
* Return:
*  Compare value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 TimerSpeech_ReadCompare(void)
{
    #if (TimerSpeech_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (TimerSpeech_CY_TCPWM_4000) */

    #if (TimerSpeech_CY_TCPWM_4000)
        currentMode = ((TimerSpeech_CONTROL_REG & TimerSpeech_UPDOWN_MASK) >> TimerSpeech_UPDOWN_SHIFT);
        
        regVal = TimerSpeech_COMP_CAP_REG;
        
        if (((uint32)TimerSpeech__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)TimerSpeech__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & TimerSpeech_16BIT_MASK);
    #else
        return (TimerSpeech_COMP_CAP_REG & TimerSpeech_16BIT_MASK);
    #endif /* (TimerSpeech_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: TimerSpeech_WriteCompareBuf
********************************************************************************
*
* Summary:
*  Writes the 16 bit compare buffer register with the new compare value. Not
*  applicable for Timer/Counter with Capture or in Quadrature Decoder modes.
*
* Parameters:
*  compareBuf: Compare value
*
* Return:
*  None
*
* Note:
*  It is not recommended to use the value equal to "0" or equal to 
*  "period value" in Center or Asymmetric align PWM modes on the 
*  PSoC 4100/PSoC 4200 devices.
*  PSoC 4000 devices write the 16 bit compare register with the decremented 
*  compare value in the Up counting mode (except 0x0u), and the incremented 
*  compare value in the Down counting mode (except 0xFFFFu).
*
*******************************************************************************/
void TimerSpeech_WriteCompareBuf(uint32 compareBuf)
{
    #if (TimerSpeech_CY_TCPWM_4000)
        uint32 currentMode;
    #endif /* (TimerSpeech_CY_TCPWM_4000) */

    #if (TimerSpeech_CY_TCPWM_4000)
        currentMode = ((TimerSpeech_CONTROL_REG & TimerSpeech_UPDOWN_MASK) >> TimerSpeech_UPDOWN_SHIFT);

        if (((uint32)TimerSpeech__COUNT_DOWN == currentMode) && (0xFFFFu != compareBuf))
        {
            compareBuf++;
        }
        else if (((uint32)TimerSpeech__COUNT_UP == currentMode) && (0u != compareBuf))
        {
            compareBuf --;
        }
        else
        {
        }
    #endif /* (TimerSpeech_CY_TCPWM_4000) */
    
    TimerSpeech_COMP_CAP_BUF_REG = (compareBuf & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadCompareBuf
********************************************************************************
*
* Summary:
*  Reads the compare buffer register. Not applicable for Timer/Counter with
*  Capture or in Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Compare buffer value
*
* Note:
*  PSoC 4000 devices read the incremented compare register value in the 
*  Up counting mode (except 0xFFFFu), and the decremented value in the 
*  Down counting mode (except 0x0u).
*
*******************************************************************************/
uint32 TimerSpeech_ReadCompareBuf(void)
{
    #if (TimerSpeech_CY_TCPWM_4000)
        uint32 currentMode;
        uint32 regVal;
    #endif /* (TimerSpeech_CY_TCPWM_4000) */

    #if (TimerSpeech_CY_TCPWM_4000)
        currentMode = ((TimerSpeech_CONTROL_REG & TimerSpeech_UPDOWN_MASK) >> TimerSpeech_UPDOWN_SHIFT);

        regVal = TimerSpeech_COMP_CAP_BUF_REG;
        
        if (((uint32)TimerSpeech__COUNT_DOWN == currentMode) && (0u != regVal))
        {
            regVal--;
        }
        else if (((uint32)TimerSpeech__COUNT_UP == currentMode) && (0xFFFFu != regVal))
        {
            regVal++;
        }
        else
        {
        }

        return (regVal & TimerSpeech_16BIT_MASK);
    #else
        return (TimerSpeech_COMP_CAP_BUF_REG & TimerSpeech_16BIT_MASK);
    #endif /* (TimerSpeech_CY_TCPWM_4000) */
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadCapture
********************************************************************************
*
* Summary:
*  Reads the captured counter value. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture value
*
*******************************************************************************/
uint32 TimerSpeech_ReadCapture(void)
{
    return (TimerSpeech_COMP_CAP_REG & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadCaptureBuf
********************************************************************************
*
* Summary:
*  Reads the capture buffer register. This API is applicable only for
*  Timer/Counter with the capture mode and Quadrature Decoder modes.
*
* Parameters:
*  None
*
* Return:
*  Capture buffer value
*
*******************************************************************************/
uint32 TimerSpeech_ReadCaptureBuf(void)
{
    return (TimerSpeech_COMP_CAP_BUF_REG & TimerSpeech_16BIT_MASK);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetCaptureMode
********************************************************************************
*
* Summary:
*  Sets the capture trigger mode. For PWM mode this is the switch input.
*  This input is not applicable to the Timer/Counter without Capture and
*  Quadrature Decoder modes.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerSpeech_TRIG_LEVEL     - Level
*     - TimerSpeech_TRIG_RISING    - Rising edge
*     - TimerSpeech_TRIG_FALLING   - Falling edge
*     - TimerSpeech_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetCaptureMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_TRIG_CONTROL1_REG &= (uint32)~TimerSpeech_CAPTURE_MASK;
    TimerSpeech_TRIG_CONTROL1_REG |= triggerMode;

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetReloadMode
********************************************************************************
*
* Summary:
*  Sets the reload trigger mode. For Quadrature Decoder mode this is the index
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerSpeech_TRIG_LEVEL     - Level
*     - TimerSpeech_TRIG_RISING    - Rising edge
*     - TimerSpeech_TRIG_FALLING   - Falling edge
*     - TimerSpeech_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetReloadMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_TRIG_CONTROL1_REG &= (uint32)~TimerSpeech_RELOAD_MASK;
    TimerSpeech_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerSpeech_RELOAD_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetStartMode
********************************************************************************
*
* Summary:
*  Sets the start trigger mode. For Quadrature Decoder mode this is the
*  phiB input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerSpeech_TRIG_LEVEL     - Level
*     - TimerSpeech_TRIG_RISING    - Rising edge
*     - TimerSpeech_TRIG_FALLING   - Falling edge
*     - TimerSpeech_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetStartMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_TRIG_CONTROL1_REG &= (uint32)~TimerSpeech_START_MASK;
    TimerSpeech_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerSpeech_START_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetStopMode
********************************************************************************
*
* Summary:
*  Sets the stop trigger mode. For PWM mode this is the kill input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerSpeech_TRIG_LEVEL     - Level
*     - TimerSpeech_TRIG_RISING    - Rising edge
*     - TimerSpeech_TRIG_FALLING   - Falling edge
*     - TimerSpeech_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetStopMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_TRIG_CONTROL1_REG &= (uint32)~TimerSpeech_STOP_MASK;
    TimerSpeech_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerSpeech_STOP_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_SetCountMode
********************************************************************************
*
* Summary:
*  Sets the count trigger mode. For Quadrature Decoder mode this is the phiA
*  input.
*
* Parameters:
*  triggerMode: Enumerated trigger mode value
*   Values:
*     - TimerSpeech_TRIG_LEVEL     - Level
*     - TimerSpeech_TRIG_RISING    - Rising edge
*     - TimerSpeech_TRIG_FALLING   - Falling edge
*     - TimerSpeech_TRIG_BOTH      - Both rising and falling edge
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetCountMode(uint32 triggerMode)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_TRIG_CONTROL1_REG &= (uint32)~TimerSpeech_COUNT_MASK;
    TimerSpeech_TRIG_CONTROL1_REG |= ((uint32)(triggerMode << TimerSpeech_COUNT_SHIFT));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_TriggerCommand
********************************************************************************
*
* Summary:
*  Triggers the designated command to occur on the designated TCPWM instances.
*  The mask can be used to apply this command simultaneously to more than one
*  instance.  This allows multiple TCPWM instances to be synchronized.
*
* Parameters:
*  mask: A combination of mask bits for each instance of the TCPWM that the
*        command should apply to.  This function from one instance can be used
*        to apply the command to any of the instances in the design.
*        The mask value for a specific instance is available with the MASK
*        define.
*  command: Enumerated command values. Capture command only applicable for
*           Timer/Counter with Capture and PWM modes.
*   Values:
*     - TimerSpeech_CMD_CAPTURE    - Trigger Capture/Switch command
*     - TimerSpeech_CMD_RELOAD     - Trigger Reload/Index command
*     - TimerSpeech_CMD_STOP       - Trigger Stop/Kill command
*     - TimerSpeech_CMD_START      - Trigger Start/phiB command
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_TriggerCommand(uint32 mask, uint32 command)
{
    uint8 enableInterrupts;

    enableInterrupts = CyEnterCriticalSection();

    TimerSpeech_COMMAND_REG = ((uint32)(mask << command));

    CyExitCriticalSection(enableInterrupts);
}


/*******************************************************************************
* Function Name: TimerSpeech_ReadStatus
********************************************************************************
*
* Summary:
*  Reads the status of the TimerSpeech.
*
* Parameters:
*  None
*
* Return:
*  Status
*   Values:
*     - TimerSpeech_STATUS_DOWN    - Set if counting down
*     - TimerSpeech_STATUS_RUNNING - Set if counter is running
*
*******************************************************************************/
uint32 TimerSpeech_ReadStatus(void)
{
    return ((TimerSpeech_STATUS_REG >> TimerSpeech_RUNNING_STATUS_SHIFT) |
            (TimerSpeech_STATUS_REG & TimerSpeech_STATUS_DOWN));
}


/*******************************************************************************
* Function Name: TimerSpeech_SetInterruptMode
********************************************************************************
*
* Summary:
*  Sets the interrupt mask to control which interrupt
*  requests generate the interrupt signal.
*
* Parameters:
*   interruptMask: Mask of bits to be enabled
*   Values:
*     - TimerSpeech_INTR_MASK_TC       - Terminal count mask
*     - TimerSpeech_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetInterruptMode(uint32 interruptMask)
{
    TimerSpeech_INTERRUPT_MASK_REG =  interruptMask;
}


/*******************************************************************************
* Function Name: TimerSpeech_GetInterruptSourceMasked
********************************************************************************
*
* Summary:
*  Gets the interrupt requests masked by the interrupt mask.
*
* Parameters:
*   None
*
* Return:
*  Masked interrupt source
*   Values:
*     - TimerSpeech_INTR_MASK_TC       - Terminal count mask
*     - TimerSpeech_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 TimerSpeech_GetInterruptSourceMasked(void)
{
    return (TimerSpeech_INTERRUPT_MASKED_REG);
}


/*******************************************************************************
* Function Name: TimerSpeech_GetInterruptSource
********************************************************************************
*
* Summary:
*  Gets the interrupt requests (without masking).
*
* Parameters:
*  None
*
* Return:
*  Interrupt request value
*   Values:
*     - TimerSpeech_INTR_MASK_TC       - Terminal count mask
*     - TimerSpeech_INTR_MASK_CC_MATCH - Compare count / capture mask
*
*******************************************************************************/
uint32 TimerSpeech_GetInterruptSource(void)
{
    return (TimerSpeech_INTERRUPT_REQ_REG);
}


/*******************************************************************************
* Function Name: TimerSpeech_ClearInterrupt
********************************************************************************
*
* Summary:
*  Clears the interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to clear
*   Values:
*     - TimerSpeech_INTR_MASK_TC       - Terminal count mask
*     - TimerSpeech_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_ClearInterrupt(uint32 interruptMask)
{
    TimerSpeech_INTERRUPT_REQ_REG = interruptMask;
}


/*******************************************************************************
* Function Name: TimerSpeech_SetInterrupt
********************************************************************************
*
* Summary:
*  Sets a software interrupt request.
*
* Parameters:
*   interruptMask: Mask of interrupts to set
*   Values:
*     - TimerSpeech_INTR_MASK_TC       - Terminal count mask
*     - TimerSpeech_INTR_MASK_CC_MATCH - Compare count / capture mask
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SetInterrupt(uint32 interruptMask)
{
    TimerSpeech_INTERRUPT_SET_REG = interruptMask;
}


/* [] END OF FILE */
