/*******************************************************************************
* File Name: TimerSpeech.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the TimerSpeech
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_TimerSpeech_H)
#define CY_TCPWM_TimerSpeech_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} TimerSpeech_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  TimerSpeech_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define TimerSpeech_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define TimerSpeech_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define TimerSpeech_CONFIG                         (1lu)

/* Quad Mode */
/* Parameters */
#define TimerSpeech_QUAD_ENCODING_MODES            (0lu)
#define TimerSpeech_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define TimerSpeech_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define TimerSpeech_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define TimerSpeech_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define TimerSpeech_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define TimerSpeech_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define TimerSpeech_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define TimerSpeech_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define TimerSpeech_TC_RUN_MODE                    (0lu)
#define TimerSpeech_TC_COUNTER_MODE                (0lu)
#define TimerSpeech_TC_COMP_CAP_MODE               (2lu)
#define TimerSpeech_TC_PRESCALER                   (0lu)

/* Signal modes */
#define TimerSpeech_TC_RELOAD_SIGNAL_MODE          (0lu)
#define TimerSpeech_TC_COUNT_SIGNAL_MODE           (3lu)
#define TimerSpeech_TC_START_SIGNAL_MODE           (0lu)
#define TimerSpeech_TC_STOP_SIGNAL_MODE            (0lu)
#define TimerSpeech_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerSpeech_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define TimerSpeech_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define TimerSpeech_TC_START_SIGNAL_PRESENT        (0lu)
#define TimerSpeech_TC_STOP_SIGNAL_PRESENT         (0lu)
#define TimerSpeech_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerSpeech_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define TimerSpeech_PWM_KILL_EVENT                 (0lu)
#define TimerSpeech_PWM_STOP_EVENT                 (0lu)
#define TimerSpeech_PWM_MODE                       (4lu)
#define TimerSpeech_PWM_OUT_N_INVERT               (0lu)
#define TimerSpeech_PWM_OUT_INVERT                 (0lu)
#define TimerSpeech_PWM_ALIGN                      (0lu)
#define TimerSpeech_PWM_RUN_MODE                   (0lu)
#define TimerSpeech_PWM_DEAD_TIME_CYCLE            (0lu)
#define TimerSpeech_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define TimerSpeech_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define TimerSpeech_PWM_COUNT_SIGNAL_MODE          (3lu)
#define TimerSpeech_PWM_START_SIGNAL_MODE          (0lu)
#define TimerSpeech_PWM_STOP_SIGNAL_MODE           (0lu)
#define TimerSpeech_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define TimerSpeech_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define TimerSpeech_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define TimerSpeech_PWM_START_SIGNAL_PRESENT       (0lu)
#define TimerSpeech_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define TimerSpeech_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define TimerSpeech_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define TimerSpeech_TC_PERIOD_VALUE                (2400lu)
#define TimerSpeech_TC_COMPARE_VALUE               (65535lu)
#define TimerSpeech_TC_COMPARE_BUF_VALUE           (65535lu)
#define TimerSpeech_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define TimerSpeech_PWM_PERIOD_VALUE               (65535lu)
#define TimerSpeech_PWM_PERIOD_BUF_VALUE           (65535lu)
#define TimerSpeech_PWM_PERIOD_SWAP                (0lu)
#define TimerSpeech_PWM_COMPARE_VALUE              (65535lu)
#define TimerSpeech_PWM_COMPARE_BUF_VALUE          (65535lu)
#define TimerSpeech_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define TimerSpeech__LEFT 0
#define TimerSpeech__RIGHT 1
#define TimerSpeech__CENTER 2
#define TimerSpeech__ASYMMETRIC 3

#define TimerSpeech__X1 0
#define TimerSpeech__X2 1
#define TimerSpeech__X4 2

#define TimerSpeech__PWM 4
#define TimerSpeech__PWM_DT 5
#define TimerSpeech__PWM_PR 6

#define TimerSpeech__INVERSE 1
#define TimerSpeech__DIRECT 0

#define TimerSpeech__CAPTURE 2
#define TimerSpeech__COMPARE 0

#define TimerSpeech__TRIG_LEVEL 3
#define TimerSpeech__TRIG_RISING 0
#define TimerSpeech__TRIG_FALLING 1
#define TimerSpeech__TRIG_BOTH 2

#define TimerSpeech__INTR_MASK_TC 1
#define TimerSpeech__INTR_MASK_CC_MATCH 2
#define TimerSpeech__INTR_MASK_NONE 0
#define TimerSpeech__INTR_MASK_TC_CC 3

#define TimerSpeech__UNCONFIG 8
#define TimerSpeech__TIMER 1
#define TimerSpeech__QUAD 3
#define TimerSpeech__PWM_SEL 7

#define TimerSpeech__COUNT_UP 0
#define TimerSpeech__COUNT_DOWN 1
#define TimerSpeech__COUNT_UPDOWN0 2
#define TimerSpeech__COUNT_UPDOWN1 3


/* Prescaler */
#define TimerSpeech_PRESCALE_DIVBY1                ((uint32)(0u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY2                ((uint32)(1u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY4                ((uint32)(2u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY8                ((uint32)(3u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY16               ((uint32)(4u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY32               ((uint32)(5u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY64               ((uint32)(6u << TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_PRESCALE_DIVBY128              ((uint32)(7u << TimerSpeech_PRESCALER_SHIFT))

/* TCPWM set modes */
#define TimerSpeech_MODE_TIMER_COMPARE             ((uint32)(TimerSpeech__COMPARE         <<  \
                                                                  TimerSpeech_MODE_SHIFT))
#define TimerSpeech_MODE_TIMER_CAPTURE             ((uint32)(TimerSpeech__CAPTURE         <<  \
                                                                  TimerSpeech_MODE_SHIFT))
#define TimerSpeech_MODE_QUAD                      ((uint32)(TimerSpeech__QUAD            <<  \
                                                                  TimerSpeech_MODE_SHIFT))
#define TimerSpeech_MODE_PWM                       ((uint32)(TimerSpeech__PWM             <<  \
                                                                  TimerSpeech_MODE_SHIFT))
#define TimerSpeech_MODE_PWM_DT                    ((uint32)(TimerSpeech__PWM_DT          <<  \
                                                                  TimerSpeech_MODE_SHIFT))
#define TimerSpeech_MODE_PWM_PR                    ((uint32)(TimerSpeech__PWM_PR          <<  \
                                                                  TimerSpeech_MODE_SHIFT))

/* Quad Modes */
#define TimerSpeech_MODE_X1                        ((uint32)(TimerSpeech__X1              <<  \
                                                                  TimerSpeech_QUAD_MODE_SHIFT))
#define TimerSpeech_MODE_X2                        ((uint32)(TimerSpeech__X2              <<  \
                                                                  TimerSpeech_QUAD_MODE_SHIFT))
#define TimerSpeech_MODE_X4                        ((uint32)(TimerSpeech__X4              <<  \
                                                                  TimerSpeech_QUAD_MODE_SHIFT))

/* Counter modes */
#define TimerSpeech_COUNT_UP                       ((uint32)(TimerSpeech__COUNT_UP        <<  \
                                                                  TimerSpeech_UPDOWN_SHIFT))
#define TimerSpeech_COUNT_DOWN                     ((uint32)(TimerSpeech__COUNT_DOWN      <<  \
                                                                  TimerSpeech_UPDOWN_SHIFT))
#define TimerSpeech_COUNT_UPDOWN0                  ((uint32)(TimerSpeech__COUNT_UPDOWN0   <<  \
                                                                  TimerSpeech_UPDOWN_SHIFT))
#define TimerSpeech_COUNT_UPDOWN1                  ((uint32)(TimerSpeech__COUNT_UPDOWN1   <<  \
                                                                  TimerSpeech_UPDOWN_SHIFT))

/* PWM output invert */
#define TimerSpeech_INVERT_LINE                    ((uint32)(TimerSpeech__INVERSE         <<  \
                                                                  TimerSpeech_INV_OUT_SHIFT))
#define TimerSpeech_INVERT_LINE_N                  ((uint32)(TimerSpeech__INVERSE         <<  \
                                                                  TimerSpeech_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define TimerSpeech_TRIG_RISING                    ((uint32)TimerSpeech__TRIG_RISING)
#define TimerSpeech_TRIG_FALLING                   ((uint32)TimerSpeech__TRIG_FALLING)
#define TimerSpeech_TRIG_BOTH                      ((uint32)TimerSpeech__TRIG_BOTH)
#define TimerSpeech_TRIG_LEVEL                     ((uint32)TimerSpeech__TRIG_LEVEL)

/* Interrupt mask */
#define TimerSpeech_INTR_MASK_TC                   ((uint32)TimerSpeech__INTR_MASK_TC)
#define TimerSpeech_INTR_MASK_CC_MATCH             ((uint32)TimerSpeech__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define TimerSpeech_CC_MATCH_SET                   (0x00u)
#define TimerSpeech_CC_MATCH_CLEAR                 (0x01u)
#define TimerSpeech_CC_MATCH_INVERT                (0x02u)
#define TimerSpeech_CC_MATCH_NO_CHANGE             (0x03u)
#define TimerSpeech_OVERLOW_SET                    (0x00u)
#define TimerSpeech_OVERLOW_CLEAR                  (0x04u)
#define TimerSpeech_OVERLOW_INVERT                 (0x08u)
#define TimerSpeech_OVERLOW_NO_CHANGE              (0x0Cu)
#define TimerSpeech_UNDERFLOW_SET                  (0x00u)
#define TimerSpeech_UNDERFLOW_CLEAR                (0x10u)
#define TimerSpeech_UNDERFLOW_INVERT               (0x20u)
#define TimerSpeech_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define TimerSpeech_PWM_MODE_LEFT                  (TimerSpeech_CC_MATCH_CLEAR        |   \
                                                         TimerSpeech_OVERLOW_SET           |   \
                                                         TimerSpeech_UNDERFLOW_NO_CHANGE)
#define TimerSpeech_PWM_MODE_RIGHT                 (TimerSpeech_CC_MATCH_SET          |   \
                                                         TimerSpeech_OVERLOW_NO_CHANGE     |   \
                                                         TimerSpeech_UNDERFLOW_CLEAR)
#define TimerSpeech_PWM_MODE_ASYM                  (TimerSpeech_CC_MATCH_INVERT       |   \
                                                         TimerSpeech_OVERLOW_SET           |   \
                                                         TimerSpeech_UNDERFLOW_CLEAR)

#if (TimerSpeech_CY_TCPWM_V2)
    #if(TimerSpeech_CY_TCPWM_4000)
        #define TimerSpeech_PWM_MODE_CENTER                (TimerSpeech_CC_MATCH_INVERT       |   \
                                                                 TimerSpeech_OVERLOW_NO_CHANGE     |   \
                                                                 TimerSpeech_UNDERFLOW_CLEAR)
    #else
        #define TimerSpeech_PWM_MODE_CENTER                (TimerSpeech_CC_MATCH_INVERT       |   \
                                                                 TimerSpeech_OVERLOW_SET           |   \
                                                                 TimerSpeech_UNDERFLOW_CLEAR)
    #endif /* (TimerSpeech_CY_TCPWM_4000) */
#else
    #define TimerSpeech_PWM_MODE_CENTER                (TimerSpeech_CC_MATCH_INVERT       |   \
                                                             TimerSpeech_OVERLOW_NO_CHANGE     |   \
                                                             TimerSpeech_UNDERFLOW_CLEAR)
#endif /* (TimerSpeech_CY_TCPWM_NEW) */

/* Command operations without condition */
#define TimerSpeech_CMD_CAPTURE                    (0u)
#define TimerSpeech_CMD_RELOAD                     (8u)
#define TimerSpeech_CMD_STOP                       (16u)
#define TimerSpeech_CMD_START                      (24u)

/* Status */
#define TimerSpeech_STATUS_DOWN                    (1u)
#define TimerSpeech_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   TimerSpeech_Init(void);
void   TimerSpeech_Enable(void);
void   TimerSpeech_Start(void);
void   TimerSpeech_Stop(void);

void   TimerSpeech_SetMode(uint32 mode);
void   TimerSpeech_SetCounterMode(uint32 counterMode);
void   TimerSpeech_SetPWMMode(uint32 modeMask);
void   TimerSpeech_SetQDMode(uint32 qdMode);

void   TimerSpeech_SetPrescaler(uint32 prescaler);
void   TimerSpeech_TriggerCommand(uint32 mask, uint32 command);
void   TimerSpeech_SetOneShot(uint32 oneShotEnable);
uint32 TimerSpeech_ReadStatus(void);

void   TimerSpeech_SetPWMSyncKill(uint32 syncKillEnable);
void   TimerSpeech_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   TimerSpeech_SetPWMDeadTime(uint32 deadTime);
void   TimerSpeech_SetPWMInvert(uint32 mask);

void   TimerSpeech_SetInterruptMode(uint32 interruptMask);
uint32 TimerSpeech_GetInterruptSourceMasked(void);
uint32 TimerSpeech_GetInterruptSource(void);
void   TimerSpeech_ClearInterrupt(uint32 interruptMask);
void   TimerSpeech_SetInterrupt(uint32 interruptMask);

void   TimerSpeech_WriteCounter(uint32 count);
uint32 TimerSpeech_ReadCounter(void);

uint32 TimerSpeech_ReadCapture(void);
uint32 TimerSpeech_ReadCaptureBuf(void);

void   TimerSpeech_WritePeriod(uint32 period);
uint32 TimerSpeech_ReadPeriod(void);
void   TimerSpeech_WritePeriodBuf(uint32 periodBuf);
uint32 TimerSpeech_ReadPeriodBuf(void);

void   TimerSpeech_WriteCompare(uint32 compare);
uint32 TimerSpeech_ReadCompare(void);
void   TimerSpeech_WriteCompareBuf(uint32 compareBuf);
uint32 TimerSpeech_ReadCompareBuf(void);

void   TimerSpeech_SetPeriodSwap(uint32 swapEnable);
void   TimerSpeech_SetCompareSwap(uint32 swapEnable);

void   TimerSpeech_SetCaptureMode(uint32 triggerMode);
void   TimerSpeech_SetReloadMode(uint32 triggerMode);
void   TimerSpeech_SetStartMode(uint32 triggerMode);
void   TimerSpeech_SetStopMode(uint32 triggerMode);
void   TimerSpeech_SetCountMode(uint32 triggerMode);

void   TimerSpeech_SaveConfig(void);
void   TimerSpeech_RestoreConfig(void);
void   TimerSpeech_Sleep(void);
void   TimerSpeech_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define TimerSpeech_BLOCK_CONTROL_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerSpeech_BLOCK_CONTROL_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define TimerSpeech_COMMAND_REG                    (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerSpeech_COMMAND_PTR                    ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define TimerSpeech_INTRRUPT_CAUSE_REG             (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerSpeech_INTRRUPT_CAUSE_PTR             ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define TimerSpeech_CONTROL_REG                    (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CTRL )
#define TimerSpeech_CONTROL_PTR                    ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CTRL )
#define TimerSpeech_STATUS_REG                     (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__STATUS )
#define TimerSpeech_STATUS_PTR                     ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__STATUS )
#define TimerSpeech_COUNTER_REG                    (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__COUNTER )
#define TimerSpeech_COUNTER_PTR                    ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__COUNTER )
#define TimerSpeech_COMP_CAP_REG                   (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CC )
#define TimerSpeech_COMP_CAP_PTR                   ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CC )
#define TimerSpeech_COMP_CAP_BUF_REG               (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerSpeech_COMP_CAP_BUF_PTR               ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__CC_BUFF )
#define TimerSpeech_PERIOD_REG                     (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__PERIOD )
#define TimerSpeech_PERIOD_PTR                     ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__PERIOD )
#define TimerSpeech_PERIOD_BUF_REG                 (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerSpeech_PERIOD_BUF_PTR                 ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define TimerSpeech_TRIG_CONTROL0_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerSpeech_TRIG_CONTROL0_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define TimerSpeech_TRIG_CONTROL1_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerSpeech_TRIG_CONTROL1_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define TimerSpeech_TRIG_CONTROL2_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerSpeech_TRIG_CONTROL2_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define TimerSpeech_INTERRUPT_REQ_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR )
#define TimerSpeech_INTERRUPT_REQ_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR )
#define TimerSpeech_INTERRUPT_SET_REG              (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerSpeech_INTERRUPT_SET_PTR              ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_SET )
#define TimerSpeech_INTERRUPT_MASK_REG             (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerSpeech_INTERRUPT_MASK_PTR             ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_MASK )
#define TimerSpeech_INTERRUPT_MASKED_REG           (*(reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_MASKED )
#define TimerSpeech_INTERRUPT_MASKED_PTR           ( (reg32 *) TimerSpeech_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define TimerSpeech_MASK                           ((uint32)TimerSpeech_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define TimerSpeech_RELOAD_CC_SHIFT                (0u)
#define TimerSpeech_RELOAD_PERIOD_SHIFT            (1u)
#define TimerSpeech_PWM_SYNC_KILL_SHIFT            (2u)
#define TimerSpeech_PWM_STOP_KILL_SHIFT            (3u)
#define TimerSpeech_PRESCALER_SHIFT                (8u)
#define TimerSpeech_UPDOWN_SHIFT                   (16u)
#define TimerSpeech_ONESHOT_SHIFT                  (18u)
#define TimerSpeech_QUAD_MODE_SHIFT                (20u)
#define TimerSpeech_INV_OUT_SHIFT                  (20u)
#define TimerSpeech_INV_COMPL_OUT_SHIFT            (21u)
#define TimerSpeech_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define TimerSpeech_RELOAD_CC_MASK                 ((uint32)(TimerSpeech_1BIT_MASK        <<  \
                                                                            TimerSpeech_RELOAD_CC_SHIFT))
#define TimerSpeech_RELOAD_PERIOD_MASK             ((uint32)(TimerSpeech_1BIT_MASK        <<  \
                                                                            TimerSpeech_RELOAD_PERIOD_SHIFT))
#define TimerSpeech_PWM_SYNC_KILL_MASK             ((uint32)(TimerSpeech_1BIT_MASK        <<  \
                                                                            TimerSpeech_PWM_SYNC_KILL_SHIFT))
#define TimerSpeech_PWM_STOP_KILL_MASK             ((uint32)(TimerSpeech_1BIT_MASK        <<  \
                                                                            TimerSpeech_PWM_STOP_KILL_SHIFT))
#define TimerSpeech_PRESCALER_MASK                 ((uint32)(TimerSpeech_8BIT_MASK        <<  \
                                                                            TimerSpeech_PRESCALER_SHIFT))
#define TimerSpeech_UPDOWN_MASK                    ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                            TimerSpeech_UPDOWN_SHIFT))
#define TimerSpeech_ONESHOT_MASK                   ((uint32)(TimerSpeech_1BIT_MASK        <<  \
                                                                            TimerSpeech_ONESHOT_SHIFT))
#define TimerSpeech_QUAD_MODE_MASK                 ((uint32)(TimerSpeech_3BIT_MASK        <<  \
                                                                            TimerSpeech_QUAD_MODE_SHIFT))
#define TimerSpeech_INV_OUT_MASK                   ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                            TimerSpeech_INV_OUT_SHIFT))
#define TimerSpeech_MODE_MASK                      ((uint32)(TimerSpeech_3BIT_MASK        <<  \
                                                                            TimerSpeech_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define TimerSpeech_CAPTURE_SHIFT                  (0u)
#define TimerSpeech_COUNT_SHIFT                    (2u)
#define TimerSpeech_RELOAD_SHIFT                   (4u)
#define TimerSpeech_STOP_SHIFT                     (6u)
#define TimerSpeech_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define TimerSpeech_CAPTURE_MASK                   ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                  TimerSpeech_CAPTURE_SHIFT))
#define TimerSpeech_COUNT_MASK                     ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                  TimerSpeech_COUNT_SHIFT))
#define TimerSpeech_RELOAD_MASK                    ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                  TimerSpeech_RELOAD_SHIFT))
#define TimerSpeech_STOP_MASK                      ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                  TimerSpeech_STOP_SHIFT))
#define TimerSpeech_START_MASK                     ((uint32)(TimerSpeech_2BIT_MASK        <<  \
                                                                  TimerSpeech_START_SHIFT))

/* MASK */
#define TimerSpeech_1BIT_MASK                      ((uint32)0x01u)
#define TimerSpeech_2BIT_MASK                      ((uint32)0x03u)
#define TimerSpeech_3BIT_MASK                      ((uint32)0x07u)
#define TimerSpeech_6BIT_MASK                      ((uint32)0x3Fu)
#define TimerSpeech_8BIT_MASK                      ((uint32)0xFFu)
#define TimerSpeech_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define TimerSpeech_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define TimerSpeech_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(TimerSpeech_QUAD_ENCODING_MODES     << TimerSpeech_QUAD_MODE_SHIFT))       |\
         ((uint32)(TimerSpeech_CONFIG                  << TimerSpeech_MODE_SHIFT)))

#define TimerSpeech_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(TimerSpeech_PWM_STOP_EVENT          << TimerSpeech_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(TimerSpeech_PWM_OUT_INVERT          << TimerSpeech_INV_OUT_SHIFT))         |\
         ((uint32)(TimerSpeech_PWM_OUT_N_INVERT        << TimerSpeech_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(TimerSpeech_PWM_MODE                << TimerSpeech_MODE_SHIFT)))

#define TimerSpeech_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(TimerSpeech_PWM_RUN_MODE         << TimerSpeech_ONESHOT_SHIFT))
            
#define TimerSpeech_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(TimerSpeech_PWM_ALIGN            << TimerSpeech_UPDOWN_SHIFT))

#define TimerSpeech_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(TimerSpeech_PWM_KILL_EVENT      << TimerSpeech_PWM_SYNC_KILL_SHIFT))

#define TimerSpeech_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(TimerSpeech_PWM_DEAD_TIME_CYCLE  << TimerSpeech_PRESCALER_SHIFT))

#define TimerSpeech_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(TimerSpeech_PWM_PRESCALER        << TimerSpeech_PRESCALER_SHIFT))

#define TimerSpeech_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(TimerSpeech_TC_PRESCALER            << TimerSpeech_PRESCALER_SHIFT))       |\
         ((uint32)(TimerSpeech_TC_COUNTER_MODE         << TimerSpeech_UPDOWN_SHIFT))          |\
         ((uint32)(TimerSpeech_TC_RUN_MODE             << TimerSpeech_ONESHOT_SHIFT))         |\
         ((uint32)(TimerSpeech_TC_COMP_CAP_MODE        << TimerSpeech_MODE_SHIFT)))
        
#define TimerSpeech_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(TimerSpeech_QUAD_PHIA_SIGNAL_MODE   << TimerSpeech_COUNT_SHIFT))           |\
         ((uint32)(TimerSpeech_QUAD_INDEX_SIGNAL_MODE  << TimerSpeech_RELOAD_SHIFT))          |\
         ((uint32)(TimerSpeech_QUAD_STOP_SIGNAL_MODE   << TimerSpeech_STOP_SHIFT))            |\
         ((uint32)(TimerSpeech_QUAD_PHIB_SIGNAL_MODE   << TimerSpeech_START_SHIFT)))

#define TimerSpeech_PWM_SIGNALS_MODES                                                              \
        (((uint32)(TimerSpeech_PWM_SWITCH_SIGNAL_MODE  << TimerSpeech_CAPTURE_SHIFT))         |\
         ((uint32)(TimerSpeech_PWM_COUNT_SIGNAL_MODE   << TimerSpeech_COUNT_SHIFT))           |\
         ((uint32)(TimerSpeech_PWM_RELOAD_SIGNAL_MODE  << TimerSpeech_RELOAD_SHIFT))          |\
         ((uint32)(TimerSpeech_PWM_STOP_SIGNAL_MODE    << TimerSpeech_STOP_SHIFT))            |\
         ((uint32)(TimerSpeech_PWM_START_SIGNAL_MODE   << TimerSpeech_START_SHIFT)))

#define TimerSpeech_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(TimerSpeech_TC_CAPTURE_SIGNAL_MODE  << TimerSpeech_CAPTURE_SHIFT))         |\
         ((uint32)(TimerSpeech_TC_COUNT_SIGNAL_MODE    << TimerSpeech_COUNT_SHIFT))           |\
         ((uint32)(TimerSpeech_TC_RELOAD_SIGNAL_MODE   << TimerSpeech_RELOAD_SHIFT))          |\
         ((uint32)(TimerSpeech_TC_STOP_SIGNAL_MODE     << TimerSpeech_STOP_SHIFT))            |\
         ((uint32)(TimerSpeech_TC_START_SIGNAL_MODE    << TimerSpeech_START_SHIFT)))
        
#define TimerSpeech_TIMER_UPDOWN_CNT_USED                                                          \
                ((TimerSpeech__COUNT_UPDOWN0 == TimerSpeech_TC_COUNTER_MODE)                  ||\
                 (TimerSpeech__COUNT_UPDOWN1 == TimerSpeech_TC_COUNTER_MODE))

#define TimerSpeech_PWM_UPDOWN_CNT_USED                                                            \
                ((TimerSpeech__CENTER == TimerSpeech_PWM_ALIGN)                               ||\
                 (TimerSpeech__ASYMMETRIC == TimerSpeech_PWM_ALIGN))               
        
#define TimerSpeech_PWM_PR_INIT_VALUE              (1u)
#define TimerSpeech_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_TimerSpeech_H */

/* [] END OF FILE */
