/*******************************************************************************
* File Name: TimerSpeech_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "TimerSpeech.h"

static TimerSpeech_BACKUP_STRUCT TimerSpeech_backup;


/*******************************************************************************
* Function Name: TimerSpeech_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: TimerSpeech_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_Sleep(void)
{
    if(0u != (TimerSpeech_BLOCK_CONTROL_REG & TimerSpeech_MASK))
    {
        TimerSpeech_backup.enableState = 1u;
    }
    else
    {
        TimerSpeech_backup.enableState = 0u;
    }

    TimerSpeech_Stop();
    TimerSpeech_SaveConfig();
}


/*******************************************************************************
* Function Name: TimerSpeech_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: TimerSpeech_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void TimerSpeech_Wakeup(void)
{
    TimerSpeech_RestoreConfig();

    if(0u != TimerSpeech_backup.enableState)
    {
        TimerSpeech_Enable();
    }
}


/* [] END OF FILE */
