/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include "led.h"
#include "BLEProcess.h"
#include "FatFs\diskio.h"
#include "FatFs\ff.h"
#include "speech.h"

//
// Defines
//

#define TRUE 0x01
#define FALSE 0x00

#define SYSTICKS    2400000

#define nLAMPCHECK
//
// Variables
//

// SD-Card

char szFileDir1[20][13];
uint8_t u8FileCountMax1; // Keeps the max numbr of found files
uint8_t u8FileCount1;    // Temporary file number

char szFileDir2[20][13];
uint8_t u8FileCountMax2; // Keeps the max numbr of found files
uint8_t u8FileCount2;    // Temporary file number

FATFS fatFs;
DIR fatDirectory;
FIL ffile;
FILINFO finfo;
uint8 resultF;

// UART

#ifndef UART__DISABLED
char szPrintf[32]; // buffer used for sprintf
#endif

// Sensor

enum HalloweenLightState_t 
{
    HL_IDLE = 0u,
    HL_TRIGGERED_BY_PIR,
    HL_TRIGGERED_BY_PIR1,
    HL_TRIGGERED_BY_PROXIMITY,
    HL_TRIGGERED_BY_PROXIMITY_ON,
    HL_TRIGGERED_BY_PROXTOUCH,
    HL_TRIGGERED_BY_PROXTOUCH_ON,
    HL_INITIALIZE_IDLE
};

enum HalloweenLightState_t enHalloweenLightState;

uint32_t u32SensorPIR;          // 1 if triggered by PIR
uint32_t u32SensorProximity;    // 1 if triggered by Proximity
uint32_t u32SensorProxTouch;    // 1 if triggered by Touched Proximity

volatile uint32_t u32Sensor_Delay;               // Prevent retriggering. Trigger only allowed if 0
volatile uint32_t u32SensorPIR_Delay;            // Prevent retriggering. Trigger only allowed if 0
volatile uint32_t u32SensorProximity_Delay;      // Prevent retriggering. Trigger only allowed if 0
volatile uint32_t u32SensorProxTouch_Delay;      // Prevent retriggering. Trigger only allowed if 0

uint32_t u32Blink_Delay_On;   // used for illumination
uint32_t u32Blink_Delay_Off;  // used for illumination

uint32_t u32IsProximitySensorActive;

#define PIR_DELAY 100           // x 100ms Systick
#define PROXIMITY_DELAY 30      // x 100ms Systick
#define PROXTOUCH_DELAY 30      // x 100ms Systick

#define PROXIMITY_BLINK_DELAY_ON  3 // x 100ms Systick
#define PROXIMITY_BLINK_DELAY_OFF 3 // x 100ms Systick

#define PROXTOUCH_BLINK_DELAY_ON  1 // x 100ms Systick
#define PROXTOUCH_BLINK_DELAY_OFF 1 // x 100ms Systick 

// Lamps(LEDs)

int32_t i32Eye1val, i32Eye2val;       // used for dimming Eye1/2: 0..255 
int8_t  i32Eye1speed, i32Eye2speed;   // used for dimming Eye1/2: 0..255 (0=off)

uint32_t u32Blink_Delay_On;   // used for illumination
uint32_t u32Blink_Delay_Off;  // used for illumination

// BLE

int8_t u8BLEconnected;
int8_t u8BLElight, u8BLElightStatus;
int8_t u8BLEsound;


//
// Interrupts
//

// Systick ... 100ms

uint8_t tickcnt;

CY_ISR(mySystick_ISR)
{ 
    if (++tickcnt == 5)
    {
        P10_LED_Write(!P10_LED_Read()); // Toggle
        tickcnt = 0;
    }

        // Delays
    if (u32SensorPIR_Delay)
    {
        u32SensorPIR_Delay--;
    }
    if (u32SensorProximity_Delay)
    {
        u32SensorProximity_Delay--;
    }
    if (u32SensorProxTouch_Delay)
    {
        u32SensorProxTouch_Delay--;
    }
    if (u32Sensor_Delay)
    {
        u32Sensor_Delay--;
    }
    
    if (u32Blink_Delay_On)
    {
        u32Blink_Delay_On--;
    }

    if (u32Blink_Delay_Off)
    {
        u32Blink_Delay_Off--;
    }
  
}

// 10kHz

CY_ISR(SpeechISR)
{
    //LAMP1_Write(!LAMP1_Read());
    TimerSpeech_ClearInterrupt(TimerSpeech_INTR_MASK_TC);

    // Update Speech Ouptut Data
    Speech_ISR();
}

// PrISM

CY_ISR(PrISM_Timer)
{
        // Eye 1
        if (i32Eye1speed != 0)
        {
            i32Eye1val = i32Eye1val + i32Eye1speed;
            if (i32Eye1val > 0xFF)
            {
                i32Eye1val = 0xFF;
                i32Eye1speed = -1 * i32Eye1speed; // change direction
            }
            else
            if (i32Eye1val < 0x00)
            {
                i32Eye1val = 0x00;
                i32Eye1speed = -1 * i32Eye1speed; // change direction
            }
        }
        
        PrISM_WritePulse0(i32Eye1val);
        
        // Eye 2
        if (i32Eye2speed != 0)
        {
            i32Eye2val = i32Eye2val + i32Eye2speed;
            if (i32Eye2val > 0xFF)
            {
                i32Eye2val = 0xFF;
                i32Eye2speed = -1 * i32Eye2speed; // change direction
            }
            else
            if (i32Eye2val < 0x00)
            {
                i32Eye2val = 0x00;
                i32Eye2speed = -1 * i32Eye2speed; // change direction
            }
        }

        PrISM_WritePulse1(i32Eye2val);
}

#ifndef BLE__DISABLED
/* ----------------- */
/* RGL LED Control   */
/* ----------------- */


void UpdateRGBcharacteristic(uint8* ledData, uint8 len, uint16 attrHandle) 
{ 
  /* 'rgbHandle' stores RGB control data parameters */ 
  CYBLE_GATT_HANDLE_VALUE_PAIR_T    rgbHandle; 
   
  /* Update RGB control handle with new values */ 
  rgbHandle.attrHandle = attrHandle; 
  rgbHandle.value.val = ledData; 
  rgbHandle.value.len = len; 
     
  /* Update the RGB LED attribute value. This will allow  
  * Client device to read the existing color values over  
  * RGB LED characteristic */      
      CyBle_GattsWriteAttributeValue(&rgbHandle,  
            FALSE,  
            &cyBle_connHandle,  
            CYBLE_GATT_DB_PEER_INITIATED); 
} 

/* ----------------- */
/* BLE EVENT HANDLER */
/* ----------------- */

void GeneralEventHandler(uint32 event, void * eventParam) 
{ 
  /* Structure to store data written by Client */   
  CYBLE_GATTS_WRITE_REQ_PARAM_T *wrReqParam; 
   
  /* 'u8BleData[]' is an array to store 4 bytes of RGB LED data*/ 
  uint8 u8BleData[RGB_CHAR_DATA_LEN]; 
   
  switch(event) 
      { 
        case CYBLE_EVT_STACK_ON: 
          u8BLEconnected = FALSE;
          /* BLE stack is on. Start BLE advertisement */ 
          CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
        break;  
     
        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED: 
          /* This event is generated at GAP disconnection. */ 
           
          /* Reset the color values*/   
          u8BleData[RED_INDEX] = FALSE; 
          u8BleData[GREEN_INDEX] = FALSE; 
          u8BleData[BLUE_INDEX] = FALSE; 
          u8BleData[INTENSITY_INDEX] = FALSE; 
           
          /* Register the new color in GATT DB*/       
          UpdateRGBcharacteristic(u8BleData, sizeof(u8BleData), CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE); 
           
          /* Restart advertisement */ 
          CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
          enHalloweenLightState = HL_INITIALIZE_IDLE;
          u8BLEconnected = FALSE;
        break;  
        
        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
        
            i32Eye1val   = 0x00;
            i32Eye1speed = 20;
            i32Eye2val   = 0x00;
            i32Eye2speed = 20;
            LAMP3_Write(0);
            LAMP4_Write(0);
                    
            u8BleData[RED_INDEX] = 0; 
            u8BleData[GREEN_INDEX] = 0; 
            u8BleData[BLUE_INDEX] = 0; 
            u8BleData[INTENSITY_INDEX] = 0; 
           
          /* Register the new color in GATT DB*/       
          UpdateRGBcharacteristic(u8BleData, sizeof(u8BleData), CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE);
          CyBle_GattsWriteRsp(cyBle_connHandle);
          u8BLEconnected = TRUE;
          break;
                    
        
        case CYBLE_EVT_GATTS_WRITE_REQ: 
        /* Extract the Write data sent by Client */ 
              wrReqParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *) eventParam; 
               
          /* If the attribute handle of the characteristic written to  
          * is equal to that of RGB_LED characteristic, then extract  
          * the RGB LED data */   
              if(CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE ==  
                                      wrReqParam->handleValPair.attrHandle) 
              { 
                /* Store RGB LED data in local array */ 
                u8BleData[RED_INDEX] =  
                           wrReqParam->handleValPair.value.val[RED_INDEX]; 
                u8BleData[GREEN_INDEX] =  
                           wrReqParam->handleValPair.value.val[GREEN_INDEX]; 
                u8BleData[BLUE_INDEX] =  
                           wrReqParam->handleValPair.value.val[BLUE_INDEX]; 
                u8BleData[INTENSITY_INDEX] =  
                           wrReqParam->handleValPair.value.val[INTENSITY_INDEX]; 
                     
                if (u8BleData[RED_INDEX] > 128)
                {
                    u8BLEsound = 1;   
                }
                
                if (u8BleData[GREEN_INDEX] > 128)
                {
                    u8BLElight = 1;   
                }

                /* Update the GATT DB for RGB LED read characteristics*/ 
                UpdateRGBcharacteristic(u8BleData, sizeof(u8BleData), CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE); 
              } 
          /* Send the response to the write request received. */ 
          CyBle_GattsWriteRsp(cyBle_connHandle);   
        break;
         
      default: 
 
         break; 
    }      
}  
#endif

int main(void)
{
    CyGlobalIntEnable; // Enable global interrupts
    
    //
    // Start the components
    //
    
    // Sytick
    
    /* Map systick ISR to the user defined ISR. SysTick_IRQn is already defined in core_cm0.h file */
    CyIntSetSysVector((SysTick_IRQn + 16), mySystick_ISR);
	
    /* Enable Systick timer with desired period/number of ticks */
    SysTick_Config(SYSTICKS); // e.g.: 12000

    // On-board LED
    
    P10_LED_Write(1);
    CyDelay(500);
    P10_LED_Write(0);
        
    // UART

    #ifndef UART__DISABLED
        UART_Start(); // UART init
        UART_PutString("\rCY-142 Halloween\r");    
    #endif
    
    u8BLEconnected = FALSE;
    
    // BLE
    #ifndef BLE__DISABLED
        #ifndef UART__DISABLED
            UART_PutString("\rInit BLE ... ");
        #endif
        CyBle_Start(GeneralEventHandler); 
        #ifndef UART__DISABLED
            UART_PutString(" done!");
        #endif
    #endif
    
    // PrISM (Lamp 1&2)
    
    isrPrISM_StartEx(PrISM_Timer);
    PrISM_Start(); 
    PrISM_WritePulse0(RGB_LED_OFF); 
    PrISM_WritePulse1(RGB_LED_OFF);
    
    // Lamp (3..8)
#ifdef LAMPCHECK    
    LAMP3_Write(1);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(1);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(1);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(1);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(1);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(1);
    CyDelay(500);
    
    LAMP3_Write(1);
    LAMP4_Write(1);
    LAMP5_Write(1);
    LAMP6_Write(1);
    LAMP7_Write(1);
    LAMP8_Write(1);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
#endif

    //
    // CapSense Proximity
    //
    
    #ifndef UART__DISABLED
        UART_PutString("\rInit CapSense ... ");
    #endif
    CapSense_Start();           // Initialize Component
    CapSense_ScanAllWidgets();  // Scan all widgets
    #ifndef UART__DISABLED
        UART_PutString(" done!");
    #endif

    // SPI1 SD-Card
    
    SPI_Start();                // SPI (SD Card) init

    // Chip select (SD-Card) is handled manually
//    (*(reg32 *)SPI_ss0_m__0__HSIOM) = 
//        ((*(reg32 *)SPI_ss0_m__0__HSIOM) & (uint32)~SPI_ss0_m__0__HSIOM_MASK) | (uint32)(SPI_HSIOM_GPIO_SEL << SPI_ss0_m__0__HSIOM_SHIFT);
//    SPI_ss0_m_Write(1);  
    SS_SD_Write(1);
    
    // Read SD Card directory
    
    #ifndef UART__DISABLED
        UART_PutString("\rRead SD Card:\r\r");
    #endif    
    u8FileCount1 = 0;
    u8FileCount2 = 0;
    
    resultF = f_mount(&fatFs, "", 1);
    if (resultF == RES_OK)
    {
        resultF = f_opendir(&fatDirectory, "/");      // open 'root' directory.
    }
    else
    {
        #ifndef UART__DISABLED
            UART_PutString("*** ERROR to read directory\r");
        #endif
    }
    
    if (resultF == RES_OK)
    {
        while(1)
        {
            resultF = f_readdir(&fatDirectory, &finfo);
            if (resultF != 0)
            {
                #ifndef UART__DISABLED
                    UART_PutString("*** ERROR to read directory\r");
                #endif
                break;
            }
            if (finfo.fname[0] == 0)             // end of directory?
            {
                #ifndef UART__DISABLED
                    UART_PutString("*** End of directory\r");
                #endif
                break;     
            }
            if (finfo.fattrib & AM_DIR)          // is it a directory?
            {
                #ifndef UART__DISABLED
                    UART_PutString(finfo.fname);
                    UART_PutString("\t\t\t<DIR>\r");
                #endif
            }
            else                                    // it is a file.
            {
                #ifndef UART__DISABLED
                    UART_PutString(finfo.fname);
                    UART_PutString("\t\t\t");     
                    itoa(finfo.fsize, szPrintf, 10);
                    UART_PutString(szPrintf);
                    UART_PutString(" Bytes \r");
                #endif
                if (finfo.fname[0] == '1')
                {
                  strcpy(&szFileDir1[u8FileCount1][0],finfo.fname); 
                  u8FileCount1 = u8FileCount1 + 1;
                }
                if (finfo.fname[0] == '2')
                {
                  strcpy(&szFileDir2[u8FileCount2][0],finfo.fname); 
                  u8FileCount2 = u8FileCount2 + 1;
                }
            }
        }
        
        f_closedir(&fatDirectory);
        resultF = f_mount(NULL, "", 1);
    }
    else
    {
        #ifndef UART__DISABLED
            UART_PutString("\r*** ERROR: Could not open Directory\r");
        #endif
    }
    
    u8FileCountMax1 = u8FileCount1;
    u8FileCountMax2 = u8FileCount2;
    
    if ((u8FileCountMax1 == 0) || (u8FileCountMax2 == 0))
    {
      LAMP8_Write(1);
      while(1);
    }
        
    #ifndef UART__DISABLED
        UART_PutString("\rFile Summary (PIR Sounds):\r");
        for (u8FileCount1=0; u8FileCount1<u8FileCountMax1; u8FileCount1++)
        {
          UART_PutString(&szFileDir1[u8FileCount1][0]); 
          UART_PutString("\r");
        }
        
        UART_PutString("\rFile Summary (ProxTouch Sounds):\r");
        for (u8FileCount2=0; u8FileCount2<u8FileCountMax2; u8FileCount2++)
        {
          UART_PutString(&szFileDir2[u8FileCount2][0]); 
          UART_PutString("\r");
        }
    #endif
    
    //
    // Speech-Out: 10kHz TIMER, IDAC
    //   
    #ifndef UART__DISABLED
        UART_PutString("\rSpeech-Out ... ");
    #endif
    
    TimerSpeech_Start(); // 10kHz TIMER (used for Speech output)
    TimerSpeech_Enable();
    isrTimerSpeech_StartEx(SpeechISR);
    isrTimerSpeech_Enable();
    Speech_Init();  
    //Speech_Out_Start("stimme.raw");
 
    enHalloweenLightState = HL_INITIALIZE_IDLE;
    
    for(;;) 
    { 
        if (u8BLEconnected == FALSE)
        {
            
            //
            // Evaluate external Sensors
            //
            
            // PIR Module
            
            if (PIRin_Read())
            {   
                u32SensorPIR = 1;   // PIR detection
            }
            else
            {   
                u32SensorPIR = 0;
            }
            
            // Proximity
            
            if(CapSense_NOT_BUSY == CapSense_IsBusy())
            {
                CapSense_ProcessAllWidgets(); // Process all widgets
                
                #ifndef CapSenseTuning__DISABLED 
                    CapSense_RunTuner();
                #endif
                
                u32IsProximitySensorActive = (CapSense_IsProximitySensorActive(CapSense_BTN0PROX_WDGT_ID, CapSense_BTN0PROX_SNS0_ID) & 0x03); // Scan result verification
                if (u32IsProximitySensorActive & 0x01)
                {   
                    u32SensorProximity = 1; // Proximity detected
                }
                else
                {   
                    u32SensorProximity = 0;
                }
                
                if (u32IsProximitySensorActive & 0x02) 
                {   
                    u32SensorProxTouch = 1; // Touch detected
                }  
                else
                {   
                    u32SensorProxTouch = 0; 
                }
                
                CapSense_ScanAllWidgets(); // Start next scan
                
            } // if(CapSense_NOT_BUSY ...
            
            //
            // For testing the sensors
            //
            
            //LAMP7_Write(u32SensorPIR);
            //LAMP7_Write(u32SensorProximity);
            //LAMP7_Write(u32SensorProxTouch);
            
            //
            // Halloween Light Control
            //
            
            switch (enHalloweenLightState)
            {
                case HL_IDLE: // Initialize
                    
                    if (u32SensorProxTouch)
                    {
                        Speech_Out_Stop(); // Stop background music
                        //Speech_Out_Start("schrei1.raw");
                        Speech_Out_Start(&szFileDir2[u8FileCount2][0]); // random sound 2
                        u32SensorProxTouch_Delay = PROXTOUCH_DELAY;
                        u32Blink_Delay_Off = 0;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                    }
                    else
                    if (u32SensorProximity)
                    {
                        u32SensorProximity_Delay = PROXIMITY_DELAY;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY;
                    }
                    else
                    if (u32SensorPIR) 
                    {
                        //Speech_Out_Start("music.raw"); // Horror Music
                        Speech_Out_Start(&szFileDir1[u8FileCount1][0]); // random sound 1
                        u32SensorPIR_Delay = PIR_DELAY;
                        enHalloweenLightState = HL_TRIGGERED_BY_PIR;
                    }
                    break;
                
                case HL_TRIGGERED_BY_PIR:
                
                    i32Eye1speed = 10;  // Increase speed for eyes
                    i32Eye2speed = 10;  // Increase speed for eyes
                    LAMP3_Write(1);
                    LAMP4_Write(1);
                    enHalloweenLightState = HL_TRIGGERED_BY_PIR1;
                    break;
                
                case HL_TRIGGERED_BY_PIR1:

                    if (u32SensorProxTouch)
                    {
                        Speech_Out_Stop(); // Stop background music
                        //Speech_Out_Start("schrei1.raw");
                        Speech_Out_Start(&szFileDir2[u8FileCount2][0]); // random sound 2
                        u32SensorProxTouch_Delay = PROXTOUCH_DELAY;
                        u32Blink_Delay_Off = 0;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                    }
                    else
                    if (u32SensorProximity)
                    {
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY;
                    }
                    else
                    if (0 == u32SensorPIR_Delay)
                    {
                        if (SPEECH_OUT_STATUS_PLAY != Speech_Out_Status())
                        {
                            enHalloweenLightState = HL_INITIALIZE_IDLE;
                        }
                    }
                                        
                    break;

                    
                case HL_TRIGGERED_BY_PROXIMITY:
                    if (0 == u32Blink_Delay_Off)
                    {
                        LAMP3_Write(1);
                        LAMP4_Write(1);
                        u32Blink_Delay_On = PROXIMITY_BLINK_DELAY_ON;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY_ON;
                    }
                    break;
                
                case HL_TRIGGERED_BY_PROXIMITY_ON:
                    
                    if (u32SensorProxTouch)
                    {
                        Speech_Out_Stop(); // Stop background music
                        //Speech_Out_Start("schrei1.raw");
                        Speech_Out_Start(&szFileDir2[u8FileCount2][0]); // random sound 2
                        u32SensorProxTouch_Delay = PROXTOUCH_DELAY;
                        u32Blink_Delay_Off = 0;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                    }
                    else
                    if (0 == u32Blink_Delay_On)
                    {
                        LAMP3_Write(0);
                        LAMP4_Write(0);
                        u32Blink_Delay_Off = PROXIMITY_BLINK_DELAY_OFF;
                        if (u32SensorProximity_Delay)
                        {
                            enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY;
                        }
                        else
                        {
                            enHalloweenLightState = HL_INITIALIZE_IDLE;    
                        }
                    }
                    break;
                    
                case HL_TRIGGERED_BY_PROXTOUCH:
                    if (0 == u32Blink_Delay_Off)
                    {
                        i32Eye1speed = 0;  // No dimming
                        i32Eye1val = 0xFF; // Full on
                        i32Eye2speed = 0;  // No dimming
                        i32Eye2val = 0xFF; // Full on
                        LAMP3_Write(1);
                        LAMP4_Write(1);
                        LAMP5_Write(1);
                        LAMP6_Write(1);
                        LAMP8_Write(1);
                        u32Blink_Delay_On = PROXTOUCH_BLINK_DELAY_ON;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH_ON;
                    }
                    break;
                
                case HL_TRIGGERED_BY_PROXTOUCH_ON:
                    if (0 == u32Blink_Delay_On)
                    {
                        i32Eye1val = 0x00; // Full off
                        i32Eye2val = 0x00; // Full off
                        LAMP3_Write(0);
                        LAMP4_Write(0);
                        LAMP5_Write(0);
                        LAMP6_Write(0);
                        LAMP8_Write(0);
                        u32Blink_Delay_Off = PROXTOUCH_BLINK_DELAY_OFF;
                        if (u32SensorProxTouch_Delay)
                        {
                            enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                        }
                        else
                        {
                            enHalloweenLightState = HL_INITIALIZE_IDLE;    
                        }
                    }
                    break;
                
                case HL_INITIALIZE_IDLE: // real idle state
                    
                    // LAMP 1&2 controlled by PrISM
                    i32Eye1val   = 0;
                    i32Eye1speed = 1;
                    i32Eye2val   = 0xFF;
                    i32Eye2speed = -1;
                    LAMP3_Write(0);
                    LAMP4_Write(0);
                    LAMP5_Write(0);
                    LAMP6_Write(0);
                    LAMP8_Write(0);
                    enHalloweenLightState = HL_IDLE;
                    break;

                default: enHalloweenLightState = HL_INITIALIZE_IDLE; // never here
            }

            // 
            // Random counter for play file
            //
            u8FileCount1 = u8FileCount1 + 1;
            if (u8FileCount1 >= u8FileCountMax1)
            {
                u8FileCount1 = 0;   
            }
            
            u8FileCount2 = u8FileCount2 + 1;
            if (u8FileCount2 >= u8FileCountMax2)
            {
                u8FileCount2 = 0;   
            }
            
        } // if (u8BLEconnected == FALSE)
        else
        {
            // Control by BLE (see GeneralEventHandler -> CYBLE_EVT_GATTS_WRITE_REQ)
            
            if (u8BLElight)
            {
                #ifndef UART__DISABLED
                UART_PutString("\rBLE Light command");
                #endif
                
                if (!u8BLElightStatus)
                {
                    // all LEDs on
                    i32Eye1speed = 0;
                    i32Eye1val   = 0xFF;
                    i32Eye2speed = 0;
                    i32Eye2val   = 0xFF;
                    LAMP3_Write(1);
                    LAMP4_Write(1);
                    LAMP5_Write(1);
                    LAMP6_Write(1);
                    LAMP8_Write(1);
                    u8BLElightStatus = 1; 
                }
                else
                {
                    // all LEDs off
                    i32Eye1speed = 0;
                    i32Eye1val   = 0x00;
                    i32Eye2speed = 0;
                    i32Eye2val   = 0x00;
                    LAMP3_Write(0);
                    LAMP4_Write(0);
                    LAMP5_Write(0);
                    LAMP6_Write(0);
                    LAMP8_Write(0);
                    u8BLElightStatus = 0;
                }
                
                u8BLElight = 0;   // clear BLE request
            }
                
            if (u8BLEsound)
            {
                #ifndef UART__DISABLED
                UART_PutString("\rBLE Sound command");
                #endif
                
                Speech_Out_Start("schrei1.raw");
                u8BLEsound = 0;   // clear BLE request   
            }  
        } // (u8BLEconnected == TRUE)
        
        // Speech processing 
        
        if (SPEECH_OUT_STATUS_PLAY == Speech_Out_Status())
        {
            Speech_Out_USB_to_Buffer();  // transfer assynchronous periodically data from USB-memory to the Speech-Out buffer    
        }
        
        // Process BLE Events. This generates events in the callback function
        
        #ifndef BLE__DISABLED
        CyBle_ProcessEvents(); 
        #endif
        
    } // for(;;)
} 

/* [] END OF FILE */
