/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include "led.h"
#include "BLEProcess.h"
#include "FatFs\diskio.h"
#include "FatFs\ff.h"
#include "speech.h"

//
// Defines
//

#define TRUE 0x01
#define FALSE 0x00

#define SYSTICKS    2400000

#define nLAMPCHECK
//
// Variables
//

// SD-Card

char szDirectory[50][13];
uint8_t u8FileCountMax; // Keeps the max numbr of found files
uint8_t u8FileCount;    // Temporary file number

FATFS fatFs;
DIR fatDirectory;
FIL ffile;
FILINFO finfo;
uint8 resultF;

// UART

#ifndef UART__DISABLED
char szPrintf[32]; // buffer used for sprintf
#endif

// Sensor

enum HalloweenLightState_t 
{
    HL_IDLE = 0u,
    HL_TRIGGERED_BY_PIR,
    HL_TRIGGERED_BY_PIR1,
    HL_TRIGGERED_BY_PROXIMITY,
    HL_TRIGGERED_BY_PROXIMITY_ON,
    HL_TRIGGERED_BY_PROXTOUCH,
    HL_TRIGGERED_BY_PROXTOUCH_ON,
    HL_INITIALIZE_IDLE
};

enum HalloweenLightState_t enHalloweenLightState;

uint32_t u32SensorPIR;          // 1 if triggered by PIR
uint32_t u32SensorProximity;    // 1 if triggered by Proximity
uint32_t u32SensorProxTouch;    // 1 if triggered by Touched Proximity

uint32_t u32Sensor_Delay;               // Prevent retriggering. Trigger only allowed if 0
uint32_t u32SensorPIR_Delay;            // Prevent retriggering. Trigger only allowed if 0
uint32_t u32SensorProximity_Delay;      // Prevent retriggering. Trigger only allowed if 0
uint32_t u32SensorProxTouch_Delay;      // Prevent retriggering. Trigger only allowed if 0

uint32_t u32Blink_Delay_On;   // used for illumination
uint32_t u32Blink_Delay_Off;  // used for illumination

uint32_t u32IsProximitySensorActive;

#define PIR_DELAY 50000         // x 100ns (10kHz) resolution
#define PROXIMITY_DELAY 20000   // x 100ns (10kHz) resolution
#define PROXTOUCH_DELAY 35000   // x 100ns (10kHz) resolution (35000 = 3.5sec)

#define PROXIMITY_BLINK_DELAY_ON  5000
#define PROXIMITY_BLINK_DELAY_OFF 5000

#define PROXTOUCH_BLINK_DELAY_ON  2000
#define PROXTOUCH_BLINK_DELAY_OFF 2000

// Lamps(LEDs)

int32_t i32Eye1val, i32Eye2val;       // used for dimming Eye1/2: 0..255 
int8_t  i32Eye1speed, i32Eye2speed;   // used for dimming Eye1/2: 0..255 (0=off)

uint32_t u32Blink_Delay_On;   // used for illumination
uint32_t u32Blink_Delay_Off;  // used for illumination

// BLE

int8_t u8BLEconnected;

//
// Interrupts
//

// Systick

uint8_t tickcnt;

CY_ISR(mySystick_ISR)
{ 
    if (++tickcnt == 5)
    {
        P10_LED_Write(!P10_LED_Read()); // Toggle
        tickcnt = 0;
    }
}

// 10kHz

CY_ISR(SpeechISR)
{
    //LAMP1_Write(!LAMP1_Read());
    TimerSpeech_ClearInterrupt(TimerSpeech_INTR_MASK_TC);

    // Delays
    if (u32SensorPIR_Delay)
    {
        u32SensorPIR_Delay--;
    }
    if (u32SensorProximity_Delay)
    {
        u32SensorProximity_Delay--;
    }
    if (u32SensorProxTouch_Delay)
    {
        u32SensorProxTouch_Delay--;
    }
    if (u32Sensor_Delay)
    {
        u32Sensor_Delay--;
    }
    
    if (u32Blink_Delay_On)
    {
        u32Blink_Delay_On--;
    }

    if (u32Blink_Delay_Off)
    {
        u32Blink_Delay_Off--;
    }
    
    // Update Speech Ouptut Data
    Speech_ISR();
}

// PrISM

CY_ISR(PrISM_Timer)
{
    if (!u8BLEconnected)
    {
        // Eye 1
        if (i32Eye1speed != 0)
        {
            i32Eye1val = i32Eye1val + i32Eye1speed;
            if (i32Eye1val > 0xFF)
            {
                i32Eye1val = 0xFF;
                i32Eye1speed = -1 * i32Eye1speed; // change direction
            }
            else
            if (i32Eye1val < 0x00)
            {
                i32Eye1val = 0x00;
                i32Eye1speed = -1 * i32Eye1speed; // change direction
            }
        }
        
        PrISM_WritePulse0(i32Eye1val);
        
        if (i32Eye2speed != 0)
        {
            i32Eye2val = i32Eye2val + i32Eye2speed;
            if (i32Eye2val > 0xFF)
            {
                i32Eye2val = 0xFF;
                i32Eye2speed = -1 * i32Eye2speed; // change direction
            }
            else
            if (i32Eye2val < 0x00)
            {
                i32Eye2val = 0x00;
                i32Eye2speed = -1 * i32Eye2speed; // change direction
            }
        }

        PrISM_WritePulse1(i32Eye2val);

    }
}

#ifndef BLE__DISABLED
/* ----------------- */
/* RGL LED Control   */
/* ----------------- */

void UpdateRGBLED(uint8* ledData, uint8 len) 
{ 
  /* Local variables to store calculated color components */ 
  uint8 calc_red; 
  uint8 calc_green; 
   
/* Check if the array has length equal to expected length for  
* RGB LED data */ 
  if(len == RGB_CHAR_DATA_LEN) 
  { 
    /* True color to be displayed is calculated on basis of color  
    * and intensity value received */ 
  calc_red = (uint8) 
(((uint16)ledData[RED_INDEX]*ledData[INTENSITY_INDEX])/RGB_LED_MAX_VAL); 
  calc_green = (uint8) 
(((uint16)ledData[GREEN_INDEX]*ledData[INTENSITY_INDEX])/RGB_LED_MAX_VAL); 
     
    /* Update the density value of the PrISM module */ 
  PrISM_WritePulse0(RGB_LED_MAX_VAL - calc_red); 
  PrISM_WritePulse1(RGB_LED_MAX_VAL - calc_green); 
  } 
} 

void UpdateRGBcharacteristic(uint8* ledData, uint8 len, uint16 attrHandle) 
{ 
  /* 'rgbHandle' stores RGB control data parameters */ 
  CYBLE_GATT_HANDLE_VALUE_PAIR_T    rgbHandle; 
   
  /* Update RGB control handle with new values */ 
  rgbHandle.attrHandle = attrHandle; 
  rgbHandle.value.val = ledData; 
  rgbHandle.value.len = len; 
     
  /* Update the RGB LED attribute value. This will allow  
  * Client device to read the existing color values over  
  * RGB LED characteristic */      
      CyBle_GattsWriteAttributeValue(&rgbHandle,  
            FALSE,  
            &cyBle_connHandle,  
            CYBLE_GATT_DB_PEER_INITIATED); 
} 

/* ----------------- */
/* BLE EVENT HANDLER */
/* ----------------- */

void GeneralEventHandler(uint32 event, void * eventParam) 
{ 
  /* Structure to store data written by Client */   
  CYBLE_GATTS_WRITE_REQ_PARAM_T *wrReqParam; 
   
  /* 'RGBledData[]' is an array to store 4 bytes of RGB LED data*/ 
  uint8 RGBledData[RGB_CHAR_DATA_LEN]; 
   
  switch(event) 
      { 
        case CYBLE_EVT_STACK_ON: 
          /* BLE stack is on. Start BLE advertisement */ 
          CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
        break;  
     
        case CYBLE_EVT_GAP_DEVICE_DISCONNECTED: 
          /* This event is generated at GAP disconnection. */ 
           
          /* Reset the color values*/   
          RGBledData[RED_INDEX] = FALSE; 
          RGBledData[GREEN_INDEX] = FALSE; 
          RGBledData[BLUE_INDEX] = FALSE; 
          RGBledData[INTENSITY_INDEX] = FALSE; 
           
          /* Switch off LEDs */ 
          UpdateRGBLED(RGBledData, sizeof(RGBledData)); 
           
          /* Register the new color in GATT DB*/       
          UpdateRGBcharacteristic(RGBledData,  
                      sizeof(RGBledData), 
                   
          CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE); 
           
          /* Restart advertisement */ 
          CyBle_GappStartAdvertisement(CYBLE_ADVERTISING_FAST); 
        
          u8BLEconnected = FALSE;
        break;  
        
        case CYBLE_EVT_GAP_DEVICE_CONNECTED:
         RGBledData[RED_INDEX] = 200; 
          RGBledData[GREEN_INDEX] = 10; 
          RGBledData[BLUE_INDEX] = 20; 
          RGBledData[INTENSITY_INDEX] = 40; 
           
          /* Switch off LEDs */ 
          UpdateRGBLED(RGBledData, sizeof(RGBledData)); 
           
          /* Register the new color in GATT DB*/       
          UpdateRGBcharacteristic(RGBledData,  
                      sizeof(RGBledData), 
                              CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE);
          CyBle_GattsWriteRsp(cyBle_connHandle);
          u8BLEconnected = TRUE;
          break;
                    
        
        case CYBLE_EVT_GATTS_WRITE_REQ: 
        /* Extract the Write data sent by Client */ 
              wrReqParam = (CYBLE_GATTS_WRITE_REQ_PARAM_T *) eventParam; 
               
          /* If the attribute handle of the characteristic written to  
          * is equal to that of RGB_LED characteristic, then extract  
          * the RGB LED data */   
              if(CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE ==  
                                      wrReqParam->handleValPair.attrHandle) 
              { 
           /* Store RGB LED data in local array */ 
                 RGBledData[RED_INDEX] =  
                               wrReqParam->handleValPair.value.val[RED_INDEX]; 
                 RGBledData[GREEN_INDEX] =  
                               wrReqParam->handleValPair.value.val[GREEN_INDEX]; 
                 RGBledData[BLUE_INDEX] =  
                               wrReqParam->handleValPair.value.val[BLUE_INDEX]; 
                 RGBledData[INTENSITY_INDEX] =  
                               wrReqParam->handleValPair.value.val[INTENSITY_INDEX]; 
                         
            /* Update the PrISM component density value to represent color */ 
                    UpdateRGBLED(RGBledData, sizeof(RGBledData)); 
                 
            /* Update the GATT DB for RGB LED read characteristics*/ 
            UpdateRGBcharacteristic(RGBledData,  
                    sizeof(RGBledData),  
                    CYBLE_RGB_LED_RGB_LED_CONTROL_CHAR_HANDLE); 
              } 
          /* Send the response to the write request received. */ 
          CyBle_GattsWriteRsp(cyBle_connHandle);   
        break;
         
      default: 
 
         break; 
    }      
}  
#endif

int main(void)
{
    CyGlobalIntEnable; // Enable global interrupts
    
    //
    // Start the components
    //
    
    // Sytick
    
    /* Map systick ISR to the user defined ISR. SysTick_IRQn is already defined in core_cm0.h file */
    CyIntSetSysVector((SysTick_IRQn + 16), mySystick_ISR);
	
    /* Enable Systick timer with desired period/number of ticks */
    SysTick_Config(SYSTICKS); // e.g.: 12000

    // On-board LED
    
    P10_LED_Write(1);
    CyDelay(500);
    P10_LED_Write(0);
        
    // UART

    #ifndef UART__DISABLED
        UART_Start(); // UART init
        UART_PutString("\rCY-142 Halloween\r");    
    #endif
    
    // BLE
    #ifndef BLE__DISABLED
        CyBle_Start(GeneralEventHandler); 
    #endif
    
    // PrISM (Lamp 1&2)
    
    isrPrISM_StartEx(PrISM_Timer);
    PrISM_Start(); 
    PrISM_WritePulse0(RGB_LED_OFF); 
    PrISM_WritePulse1(RGB_LED_OFF);
    
    // Lamp (3..8)
#ifdef LAMPCHECK    
    LAMP3_Write(1);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(1);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(1);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(1);
    LAMP7_Write(0);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(1);
    LAMP8_Write(0);
    CyDelay(500);
    
    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(1);
    CyDelay(500);
    
    LAMP3_Write(1);
    LAMP4_Write(1);
    LAMP5_Write(1);
    LAMP6_Write(1);
    LAMP7_Write(1);
    LAMP8_Write(1);
    CyDelay(500);

    LAMP3_Write(0);
    LAMP4_Write(0);
    LAMP5_Write(0);
    LAMP6_Write(0);
    LAMP7_Write(0);
    LAMP8_Write(0);
#endif

//    // SPI1 SD-Card
//    
//    SPI_Start();                // SPI (SD Card) init
//                                // Chip select (SD-Card) is handled manually
//    (*(reg32 *)SPI_ss0_m__0__HSIOM) = 
//        ((*(reg32 *)SPI_ss0_m__0__HSIOM) & (uint32)~SPI_ss0_m__0__HSIOM_MASK) | (uint32)(SPI_HSIOM_GPIO_SEL << SPI_ss0_m__0__HSIOM_SHIFT);
//    SPI_ss0_m_Write(1);  
//    
//    // Read SD Card directory
//    
//    #ifndef UART__DISABLED
//        UART_PutString("\rRead SD Card\r");
//    #endif    
//    u8FileCount = 0;
//    resultF = f_mount(&fatFs, "", 1);
//    if (resultF == RES_OK)
//    {
//        resultF = f_opendir(&fatDirectory, "/");      // open 'root' directory.
//    }
//    else
//    {
//        #ifndef UART__DISABLED
//            UART_PutString("*** ERROR to read directory\r");
//        #endif
//    }
//    
//    if (resultF == RES_OK)
//    {
//        while(1)
//        {
//            resultF = f_readdir(&fatDirectory, &finfo);
//            if (resultF != 0)
//            {
//                #ifndef UART__DISABLED
//                    UART_PutString("*** ERROR to read directory\r");
//                #endif
//                break;
//            }
//            if (finfo.fname[0] == 0)             // end of directory?
//            {
//                #ifndef UART__DISABLED
//                    UART_PutString("*** End of directory\r");
//                #endif
//                break;     
//            }
//            if (finfo.fattrib & AM_DIR)          // is it a directory?
//            {
//                #ifndef UART__DISABLED
//                    UART_PutString(finfo.fname);
//                    UART_PutString("\t\t\t<DIR>\r");
//                #endif
//            }
//            else                                    // it is a file.
//            {
//                #ifndef UART__DISABLED
//                    UART_PutString(finfo.fname);
//                    UART_PutString("\t\t\t");     
//                    itoa(finfo.fsize, szPrintf, 10);
//                    UART_PutString(szPrintf);
//                    UART_PutString(" Bytes \r");
//                #endif
//                if (finfo.fname[0] == '1')
//                {
//                  strcpy(&szDirectory[u8FileCount][0],finfo.fname); 
//                  u8FileCount = u8FileCount + 1;
//                }
//            }
//        }
//        
//        f_closedir(&fatDirectory);
//        resultF = f_mount(NULL, "", 1);
//    }
//    else
//    {
//        #ifndef UART__DISABLED
//            UART_PutString("\r*** ERROR: Could not open Directory\r");
//        #endif
//    }
//    
//    u8FileCountMax = u8FileCount;
//    
//    #ifndef UART__DISABLED
//        UART_PutString("\rFile Summary:\r");
//        for (u8FileCount=0; u8FileCount<u8FileCountMax; u8FileCount++)
//        {
//          UART_PutString(&szDirectory[u8FileCount][0]); 
//          UART_PutString("\r");
//        }
//    #endif
//    
//    //
//    // Speech-Out: 10kHz TIMER, IDAC
//    //   
//    #ifndef UART__DISABLED
//        UART_PutString("\rSpeech-Out ... ");
//    #endif
//    
//    TimerSpeech_Start(); // 10kHz TIMER (used for Speech output)
//    TimerSpeech_Enable();
//    isrTimerSpeech_StartEx(SpeechISR);
//    isrTimerSpeech_Enable();
//    Speech_Init();  
//    Speech_Out_Start("stimme.raw");
 
    enHalloweenLightState = HL_INITIALIZE_IDLE;
    
    for(;;) 
    { 
        if (u8BLEconnected == FALSE)
        {
            
            //
            // Evaluate external Sensors
            //
            
            // PIR Module
            
            if (PIRin_Read())
            {   
                u32SensorPIR = 1;   // PIR detection
            }
            else
            {   
                u32SensorPIR = 0;
            }
            
            
            // Proximity
            
            if(CapSense_NOT_BUSY == CapSense_IsBusy())
            {
                CapSense_ProcessAllWidgets(); // Process all widgets
                
                #ifndef CapSenseTuning__DISABLED 
                    CapSense_RunTuner();
                #endif
                
                u32IsProximitySensorActive = (CapSense_IsProximitySensorActive(CapSense_BTN0PROX_WDGT_ID, CapSense_BTN0PROX_SNS0_ID) & 0x03); // Scan result verification
                if (u32IsProximitySensorActive & 0x01)
                {   
                    u32SensorProximity = 1; // Proximity detected
                }
                else
                {   
                    u32SensorProximity = 0;
                }
                
                if (u32IsProximitySensorActive & 0x02) 
                {   
                    u32SensorProxTouch = 1; // Touch detected
                }  
                else
                {   
                    u32SensorProxTouch = 0; 
                }
                
                CapSense_ScanAllWidgets(); // Start next scan
                
            } // if(CapSense_NOT_BUSY ...
            
            //
            // For testing the sensors
            //
            
            LAMP6_Write(u32SensorPIR);
            LAMP7_Write(u32SensorProximity);
            LAMP8_Write(u32SensorProxTouch);
            
            //
            // React on the external sensor status, depending on the priority Touch -> Proximity -> PIR
            //
            
            if (u32SensorProxTouch)
            {
                if (0 == u32SensorProxTouch_Delay)
                {
                    Speech_Out_Stop(); // Stop background music
                    //Speech_Out_Start("schrei1.raw");
                    Speech_Out_Start(&szDirectory[u8FileCount][0]); // random sound
                    u32SensorProxTouch_Delay = PROXTOUCH_DELAY;
                    enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                }
            }
            else
            if (u32SensorProximity)
            {
                if (0 == u32SensorProximity_Delay)
                {
                    u32SensorProximity_Delay = PROXIMITY_DELAY;
                    enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY;
                }
            }
            else
            if (        (u32SensorPIR) 
                    &&  (0 == u32SensorPIR_Delay) 
                    &&  (0 == u32SensorProximity_Delay)
                    &&  (0 == u32SensorProxTouch_Delay))
            {
                if (SPEECH_OUT_STATUS_PLAY != Speech_Out_Status())
                {
                    Speech_Out_Start("music.raw"); // Horror Music
                }

                u32SensorPIR_Delay = PIR_DELAY;
                enHalloweenLightState = HL_TRIGGERED_BY_PIR;
            }
            
            //
            // Halloween Light Control
            //
            
            switch (enHalloweenLightState)
            {
                case HL_IDLE: // Initialize
                    break;
                
                case HL_TRIGGERED_BY_PIR:
                
                    i32Eye1speed = 10;  // Increase speed for eyes
                    i32Eye2speed = 10;  // Increase speed for eyes
                    LAMP3_Write(1);
                    LAMP4_Write(1);
                    enHalloweenLightState = HL_TRIGGERED_BY_PIR1;
                    break;
                
                case HL_TRIGGERED_BY_PIR1:
                    if (0 == u32SensorPIR_Delay)
                    {
                        enHalloweenLightState = HL_INITIALIZE_IDLE;
                    }
                    break;
                    
                case HL_TRIGGERED_BY_PROXIMITY:
                    if (0 == u32Blink_Delay_Off)
                    {
                        LAMP3_Write(1);
                        LAMP4_Write(1);
                        u32Blink_Delay_On = PROXIMITY_BLINK_DELAY_ON;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY_ON;
                    }
                    break;
                
                case HL_TRIGGERED_BY_PROXIMITY_ON:
                    if (0 == u32Blink_Delay_On)
                    {
                        LAMP3_Write(0);
                        LAMP4_Write(0);
                        u32Blink_Delay_Off = PROXIMITY_BLINK_DELAY_OFF;
                        if (u32SensorProximity_Delay)
                        {
                            enHalloweenLightState = HL_TRIGGERED_BY_PROXIMITY;
                        }
                        else
                        {
                            enHalloweenLightState = HL_INITIALIZE_IDLE;    
                        }
                    }
                    break;
                    
                case HL_TRIGGERED_BY_PROXTOUCH:
                    if (0 == u32Blink_Delay_Off)
                    {
                        i32Eye1speed = 0;  // No dimming
                        i32Eye1val = 0xFF; // Full on
                        i32Eye2speed = 0;  // No dimming
                        i32Eye2val = 0xFF; // Full on
                        LAMP3_Write(1);
                        LAMP4_Write(1);
                        u32Blink_Delay_On = PROXTOUCH_BLINK_DELAY_ON;
                        enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH_ON;
                    }
                    break;
                
                case HL_TRIGGERED_BY_PROXTOUCH_ON:
                    if (0 == u32Blink_Delay_On)
                    {
                        i32Eye1val = 0x00; // Full off
                        i32Eye2val = 0x00; // Full off
                        LAMP3_Write(0);
                        LAMP4_Write(0);
                        u32Blink_Delay_Off = PROXTOUCH_BLINK_DELAY_OFF;
                        if (u32SensorProxTouch_Delay)
                        {
                            enHalloweenLightState = HL_TRIGGERED_BY_PROXTOUCH;
                        }
                        else
                        {
                            enHalloweenLightState = HL_INITIALIZE_IDLE;    
                        }
                    }
                    break;
                
                case HL_INITIALIZE_IDLE: // real idle state
                    
                    // LAMP 1&2 controlled by PrISM
                    i32Eye1val   = 0;
                    i32Eye1speed = 2;
                    i32Eye2val   = 0xFF;
                    i32Eye2speed = -2;
                    LAMP3_Write(0);
                    LAMP4_Write(0);
                    enHalloweenLightState = HL_IDLE;
                    break;

                default: enHalloweenLightState = HL_IDLE; // never here
            }

            // 
            // Random counter for play file
            //
            u8FileCount = u8FileCount + 1;
            if (u8FileCount >= u8FileCountMax)
            {
                u8FileCount = 0;   
            }
        } // if (u8BLEconnected == FALSE)
        else
        {
            // Control by BLE
            
            
            
        }
        
        // Speech processing 
        
        if (SPEECH_OUT_STATUS_PLAY == Speech_Out_Status())
        {
            Speech_Out_USB_to_Buffer();  // transfer assynchronous periodically data from USB-memory to the Speech-Out buffer    
        }
        
        // Process BLE Events. This generates events in the callback function
        
        #ifndef BLE__DISABLED
        CyBle_ProcessEvents(); 
        #endif
        
    } // for(;;)
} 

/* [] END OF FILE */
